import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::ApiGateway::DomainNameV2.
 */
export declare function getDomainNameV2(args: GetDomainNameV2Args, opts?: pulumi.InvokeOptions): Promise<GetDomainNameV2Result>;
export interface GetDomainNameV2Args {
    /**
     * The amazon resource name (ARN) of the domain name resource.
     */
    domainNameArn: string;
}
export interface GetDomainNameV2Result {
    /**
     * The reference to an AWS -managed certificate that will be used by the private endpoint for this domain name. AWS Certificate Manager is the only supported source.
     */
    readonly certificateArn?: string;
    /**
     * The amazon resource name (ARN) of the domain name resource.
     */
    readonly domainNameArn?: string;
    /**
     * The domain name ID.
     */
    readonly domainNameId?: string;
    /**
     * A stringified JSON policy document that applies to the `execute-api` service for this DomainName regardless of the caller and Method configuration. You can use `Fn::ToJsonString` to enter your `policy` . For more information, see [Fn::ToJsonString](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-ToJsonString.html) .
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ApiGateway::DomainNameV2` for more information about the expected schema for this property.
     */
    readonly policy?: any;
    /**
     * The valid routing modes are [BASE_PATH_MAPPING_ONLY], [ROUTING_RULE_THEN_BASE_PATH_MAPPING] and [ROUTING_RULE_ONLY]. All other inputs are invalid.
     */
    readonly routingMode?: enums.apigateway.DomainNameV2RoutingMode;
    /**
     * The collection of tags. Each tag element is associated with a given resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::ApiGateway::DomainNameV2.
 */
export declare function getDomainNameV2Output(args: GetDomainNameV2OutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDomainNameV2Result>;
export interface GetDomainNameV2OutputArgs {
    /**
     * The amazon resource name (ARN) of the domain name resource.
     */
    domainNameArn: pulumi.Input<string>;
}
