import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGateway::GatewayResponse`` resource creates a gateway response for your API. When you delete a stack containing this resource, your custom gateway responses are reset. For more information, see [API Gateway Responses](https://docs.aws.amazon.com/apigateway/latest/developerguide/customize-gateway-responses.html#api-gateway-gatewayResponse-definition) in the *API Gateway Developer Guide*.
 */
export declare function getGatewayResponse(args: GetGatewayResponseArgs, opts?: pulumi.InvokeOptions): Promise<GetGatewayResponseResult>;
export interface GetGatewayResponseArgs {
    /**
     * The ID for the gateway response. For example: `abc123` .
     */
    id: string;
}
export interface GetGatewayResponseResult {
    /**
     * The ID for the gateway response. For example: `abc123` .
     */
    readonly id?: string;
    /**
     * Response parameters (paths, query strings and headers) of the GatewayResponse as a string-to-string map of key-value pairs.
     */
    readonly responseParameters?: {
        [key: string]: string;
    };
    /**
     * Response templates of the GatewayResponse as a string-to-string map of key-value pairs.
     */
    readonly responseTemplates?: {
        [key: string]: string;
    };
    /**
     * The HTTP status code for this GatewayResponse.
     */
    readonly statusCode?: string;
}
/**
 * The ``AWS::ApiGateway::GatewayResponse`` resource creates a gateway response for your API. When you delete a stack containing this resource, your custom gateway responses are reset. For more information, see [API Gateway Responses](https://docs.aws.amazon.com/apigateway/latest/developerguide/customize-gateway-responses.html#api-gateway-gatewayResponse-definition) in the *API Gateway Developer Guide*.
 */
export declare function getGatewayResponseOutput(args: GetGatewayResponseOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetGatewayResponseResult>;
export interface GetGatewayResponseOutputArgs {
    /**
     * The ID for the gateway response. For example: `abc123` .
     */
    id: pulumi.Input<string>;
}
