import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGatewayV2::VpcLink`` resource creates a VPC link. Supported only for HTTP APIs. The VPC link status must transition from ``PENDING`` to ``AVAILABLE`` to successfully create a VPC link, which can take up to 10 minutes. To learn more, see [Working with VPC Links for HTTP APIs](https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-vpc-links.html) in the *API Gateway Developer Guide*.
 */
export declare function getVpcLink(args: GetVpcLinkArgs, opts?: pulumi.InvokeOptions): Promise<GetVpcLinkResult>;
export interface GetVpcLinkArgs {
    /**
     * The VPC link ID.
     */
    vpcLinkId: string;
}
export interface GetVpcLinkResult {
    /**
     * The name of the VPC link.
     */
    readonly name?: string;
    /**
     * The collection of tags. Each tag element is associated with a given resource.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * The VPC link ID.
     */
    readonly vpcLinkId?: string;
}
/**
 * The ``AWS::ApiGatewayV2::VpcLink`` resource creates a VPC link. Supported only for HTTP APIs. The VPC link status must transition from ``PENDING`` to ``AVAILABLE`` to successfully create a VPC link, which can take up to 10 minutes. To learn more, see [Working with VPC Links for HTTP APIs](https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-vpc-links.html) in the *API Gateway Developer Guide*.
 */
export declare function getVpcLinkOutput(args: GetVpcLinkOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetVpcLinkResult>;
export interface GetVpcLinkOutputArgs {
    /**
     * The VPC link ID.
     */
    vpcLinkId: pulumi.Input<string>;
}
