import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::ApplicationInsights::Application
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * The ARN of the ApplicationInsights application.
     */
    readonly applicationArn: pulumi.Output<string>;
    /**
     * If set to true, the managed policies for SSM and CW will be attached to the instance roles if they are missing
     */
    readonly attachMissingPermission: pulumi.Output<boolean | undefined>;
    /**
     * If set to true, application will be configured with recommended monitoring configuration.
     */
    readonly autoConfigurationEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The monitoring settings of the components.
     */
    readonly componentMonitoringSettings: pulumi.Output<outputs.applicationinsights.ApplicationComponentMonitoringSetting[] | undefined>;
    /**
     * The custom grouped components.
     */
    readonly customComponents: pulumi.Output<outputs.applicationinsights.ApplicationCustomComponent[] | undefined>;
    /**
     * Indicates whether Application Insights can listen to CloudWatch events for the application resources.
     */
    readonly cweMonitorEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The grouping type of the application
     */
    readonly groupingType: pulumi.Output<enums.applicationinsights.ApplicationGroupingType | undefined>;
    /**
     * The log pattern sets.
     */
    readonly logPatternSets: pulumi.Output<outputs.applicationinsights.ApplicationLogPatternSet[] | undefined>;
    /**
     * When set to true, creates opsItems for any problems detected on an application.
     */
    readonly opsCenterEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The SNS topic provided to Application Insights that is associated to the created opsItem.
     */
    readonly opsItemSnsTopicArn: pulumi.Output<string | undefined>;
    /**
     * The name of the resource group.
     */
    readonly resourceGroupName: pulumi.Output<string>;
    /**
     * Application Insights sends notifications to this SNS topic whenever there is a problem update in the associated application.
     */
    readonly snsNotificationArn: pulumi.Output<string | undefined>;
    /**
     * The tags of Application Insights application.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * If set to true, the managed policies for SSM and CW will be attached to the instance roles if they are missing
     */
    attachMissingPermission?: pulumi.Input<boolean>;
    /**
     * If set to true, application will be configured with recommended monitoring configuration.
     */
    autoConfigurationEnabled?: pulumi.Input<boolean>;
    /**
     * The monitoring settings of the components.
     */
    componentMonitoringSettings?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationComponentMonitoringSettingArgs>[]>;
    /**
     * The custom grouped components.
     */
    customComponents?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationCustomComponentArgs>[]>;
    /**
     * Indicates whether Application Insights can listen to CloudWatch events for the application resources.
     */
    cweMonitorEnabled?: pulumi.Input<boolean>;
    /**
     * The grouping type of the application
     */
    groupingType?: pulumi.Input<enums.applicationinsights.ApplicationGroupingType>;
    /**
     * The log pattern sets.
     */
    logPatternSets?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationLogPatternSetArgs>[]>;
    /**
     * When set to true, creates opsItems for any problems detected on an application.
     */
    opsCenterEnabled?: pulumi.Input<boolean>;
    /**
     * The SNS topic provided to Application Insights that is associated to the created opsItem.
     */
    opsItemSnsTopicArn?: pulumi.Input<string>;
    /**
     * The name of the resource group.
     */
    resourceGroupName: pulumi.Input<string>;
    /**
     * Application Insights sends notifications to this SNS topic whenever there is a problem update in the associated application.
     */
    snsNotificationArn?: pulumi.Input<string>;
    /**
     * The tags of Application Insights application.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
