import * as pulumi from "@pulumi/pulumi";
/**
 * Describes an AWS App Runner automatic configuration resource that enables automatic scaling of instances used to process web requests. You can share an auto scaling configuration across multiple services.
 */
export declare function getAutoScalingConfiguration(args: GetAutoScalingConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetAutoScalingConfigurationResult>;
export interface GetAutoScalingConfigurationArgs {
    /**
     * The Amazon Resource Name (ARN) of this auto scaling configuration.
     */
    autoScalingConfigurationArn: string;
}
export interface GetAutoScalingConfigurationResult {
    /**
     * The Amazon Resource Name (ARN) of this auto scaling configuration.
     */
    readonly autoScalingConfigurationArn?: string;
    /**
     * The revision of this auto scaling configuration. It's unique among all the active configurations ("Status": "ACTIVE") that share the same AutoScalingConfigurationName.
     */
    readonly autoScalingConfigurationRevision?: number;
    /**
     * It's set to true for the configuration with the highest Revision among all configurations that share the same AutoScalingConfigurationName. It's set to false otherwise. App Runner temporarily doubles the number of provisioned instances during deployments, to maintain the same capacity for both old and new code.
     */
    readonly latest?: boolean;
}
/**
 * Describes an AWS App Runner automatic configuration resource that enables automatic scaling of instances used to process web requests. You can share an auto scaling configuration across multiple services.
 */
export declare function getAutoScalingConfigurationOutput(args: GetAutoScalingConfigurationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAutoScalingConfigurationResult>;
export interface GetAutoScalingConfigurationOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of this auto scaling configuration.
     */
    autoScalingConfigurationArn: pulumi.Input<string>;
}
