import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppStream::Application
 */
export declare function getApplication(args: GetApplicationArgs, opts?: pulumi.InvokeOptions): Promise<GetApplicationResult>;
export interface GetApplicationArgs {
    /**
     * The ARN of the application.
     */
    arn: string;
}
export interface GetApplicationResult {
    /**
     * The app block ARN with which the application should be associated.
     */
    readonly appBlockArn?: string;
    /**
     * The ARN of the application.
     */
    readonly arn?: string;
    /**
     * The time when the application was created.
     */
    readonly createdTime?: string;
    /**
     * The description of the application.
     */
    readonly description?: string;
    /**
     * The display name of the application. This name is visible to users in the application catalog.
     */
    readonly displayName?: string;
    /**
     * The icon S3 location of the application.
     */
    readonly iconS3Location?: outputs.appstream.ApplicationS3Location;
    /**
     * The launch parameters of the application.
     */
    readonly launchParameters?: string;
    /**
     * The launch path of the application.
     */
    readonly launchPath?: string;
    /**
     * The tags of the application.
     */
    readonly tags?: (outputs.appstream.ApplicationTag0Properties | outputs.appstream.ApplicationTag1Properties)[];
    /**
     * The working directory of the application.
     */
    readonly workingDirectory?: string;
}
/**
 * Resource Type definition for AWS::AppStream::Application
 */
export declare function getApplicationOutput(args: GetApplicationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApplicationResult>;
export interface GetApplicationOutputArgs {
    /**
     * The ARN of the application.
     */
    arn: pulumi.Input<string>;
}
