import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::APS::Workspace
 */
export declare function getWorkspace(args: GetWorkspaceArgs, opts?: pulumi.InvokeOptions): Promise<GetWorkspaceResult>;
export interface GetWorkspaceArgs {
    /**
     * Workspace arn.
     */
    arn: string;
}
export interface GetWorkspaceResult {
    /**
     * The AMP Workspace alert manager definition data
     */
    readonly alertManagerDefinition?: string;
    /**
     * AMP Workspace alias.
     */
    readonly alias?: string;
    /**
     * Workspace arn.
     */
    readonly arn?: string;
    /**
     * Contains information about the current rules and alerting logging configuration for the workspace.
     *
     * > These logging configurations are only for rules and alerting logs.
     */
    readonly loggingConfiguration?: outputs.aps.WorkspaceLoggingConfiguration;
    /**
     * AMP Workspace prometheus endpoint
     */
    readonly prometheusEndpoint?: string;
    /**
     * The definition of logging configuration in an Amazon Managed Service for Prometheus workspace.
     */
    readonly queryLoggingConfiguration?: outputs.aps.WorkspaceQueryLoggingConfiguration;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Use this structure to define label sets and the ingestion limits for time series that match label sets, and to specify the retention period of the workspace.
     */
    readonly workspaceConfiguration?: outputs.aps.WorkspaceConfiguration;
    /**
     * Required to identify a specific APS Workspace.
     */
    readonly workspaceId?: string;
}
/**
 * Resource Type definition for AWS::APS::Workspace
 */
export declare function getWorkspaceOutput(args: GetWorkspaceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWorkspaceResult>;
export interface GetWorkspaceOutputArgs {
    /**
     * Workspace arn.
     */
    arn: pulumi.Input<string>;
}
