import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::ARCZonalShift::ZonalAutoshiftConfiguration Resource Type
 */
export declare function getZonalAutoshiftConfiguration(args: GetZonalAutoshiftConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetZonalAutoshiftConfigurationResult>;
export interface GetZonalAutoshiftConfigurationArgs {
    /**
     * The identifier for the resource that AWS shifts traffic for. The identifier is the Amazon Resource Name (ARN) for the resource.
     *
     * At this time, supported resources are Network Load Balancers and Application Load Balancers.
     */
    resourceIdentifier: string;
}
export interface GetZonalAutoshiftConfigurationResult {
    /**
     * A practice run configuration for a resource includes the Amazon CloudWatch alarms that you've specified for a practice run, as well as any blocked dates or blocked windows for the practice run. When a resource has a practice run configuration, ARC shifts traffic for the resource weekly for practice runs.
     *
     * Practice runs are required for zonal autoshift. The zonal shifts that ARC starts for practice runs help you to ensure that shifting away traffic from an Availability Zone during an autoshift is safe for your application.
     *
     * You can update or delete a practice run configuration. Before you delete a practice run configuration, you must disable zonal autoshift for the resource. A practice run configuration is required when zonal autoshift is enabled.
     */
    readonly practiceRunConfiguration?: outputs.arczonalshift.ZonalAutoshiftConfigurationPracticeRunConfiguration;
    /**
     * When zonal autoshift is `ENABLED` , you authorize AWS to shift away resource traffic for an application from an Availability Zone during events, on your behalf, to help reduce time to recovery. Traffic is also shifted away for the required weekly practice runs.
     */
    readonly zonalAutoshiftStatus?: enums.arczonalshift.ZonalAutoshiftConfigurationZonalAutoshiftStatus;
}
/**
 * Definition of AWS::ARCZonalShift::ZonalAutoshiftConfiguration Resource Type
 */
export declare function getZonalAutoshiftConfigurationOutput(args: GetZonalAutoshiftConfigurationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZonalAutoshiftConfigurationResult>;
export interface GetZonalAutoshiftConfigurationOutputArgs {
    /**
     * The identifier for the resource that AWS shifts traffic for. The identifier is the Amazon Resource Name (ARN) for the resource.
     *
     * At this time, supported resources are Network Load Balancers and Application Load Balancers.
     */
    resourceIdentifier: pulumi.Input<string>;
}
