import * as pulumi from "@pulumi/pulumi";
/**
 * Resource schema for AWS::Athena::NamedQuery
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const athenaNamedQuery = new aws_native.athena.NamedQuery("athenaNamedQuery", {
 *     database: "swfmetadata",
 *     description: "A query that selects all aggregated data",
 *     name: "MostExpensiveWorkflow",
 *     queryString: "SELECT workflowname, AVG(activitytaskstarted) AS AverageWorkflow FROM swfmetadata WHERE year='17' AND GROUP BY workflowname ORDER BY AverageWorkflow DESC LIMIT 10",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const athenaNamedQuery = new aws_native.athena.NamedQuery("athenaNamedQuery", {
 *     database: "swfmetadata",
 *     description: "A query that selects all aggregated data",
 *     name: "MostExpensiveWorkflow",
 *     queryString: "SELECT workflowname, AVG(activitytaskstarted) AS AverageWorkflow FROM swfmetadata WHERE year='17' AND GROUP BY workflowname ORDER BY AverageWorkflow DESC LIMIT 10",
 * });
 *
 * ```
 */
export declare class NamedQuery extends pulumi.CustomResource {
    /**
     * Get an existing NamedQuery resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): NamedQuery;
    /**
     * Returns true if the given object is an instance of NamedQuery.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NamedQuery;
    /**
     * The database to which the query belongs.
     */
    readonly database: pulumi.Output<string>;
    /**
     * The query description.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The query name.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The unique ID of the query.
     */
    readonly namedQueryId: pulumi.Output<string>;
    /**
     * The contents of the query with all query statements.
     */
    readonly queryString: pulumi.Output<string>;
    /**
     * The name of the workgroup that contains the named query.
     */
    readonly workGroup: pulumi.Output<string | undefined>;
    /**
     * Create a NamedQuery resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: NamedQueryArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a NamedQuery resource.
 */
export interface NamedQueryArgs {
    /**
     * The database to which the query belongs.
     */
    database: pulumi.Input<string>;
    /**
     * The query description.
     */
    description?: pulumi.Input<string>;
    /**
     * The query name.
     */
    name?: pulumi.Input<string>;
    /**
     * The contents of the query with all query statements.
     */
    queryString: pulumi.Input<string>;
    /**
     * The name of the workgroup that contains the named query.
     */
    workGroup?: pulumi.Input<string>;
}
