import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Bedrock::IntelligentPromptRouter Resource Type
 */
export declare class IntelligentPromptRouter extends pulumi.CustomResource {
    /**
     * Get an existing IntelligentPromptRouter resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IntelligentPromptRouter;
    /**
     * Returns true if the given object is an instance of IntelligentPromptRouter.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IntelligentPromptRouter;
    /**
     * Time Stamp
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Description of the Prompt Router.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The default model to use when the routing criteria is not met.
     */
    readonly fallbackModel: pulumi.Output<outputs.bedrock.IntelligentPromptRouterPromptRouterTargetModel>;
    /**
     * List of model configuration
     */
    readonly models: pulumi.Output<outputs.bedrock.IntelligentPromptRouterPromptRouterTargetModel[]>;
    /**
     * Arn of the Prompt Router.
     */
    readonly promptRouterArn: pulumi.Output<string>;
    /**
     * Name of the Prompt Router.
     */
    readonly promptRouterName: pulumi.Output<string>;
    /**
     * Routing criteria for a prompt router.
     */
    readonly routingCriteria: pulumi.Output<outputs.bedrock.IntelligentPromptRouterRoutingCriteria>;
    /**
     * The router's status.
     */
    readonly status: pulumi.Output<enums.bedrock.IntelligentPromptRouterPromptRouterStatus>;
    /**
     * List of Tags
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The router's type.
     */
    readonly type: pulumi.Output<enums.bedrock.IntelligentPromptRouterPromptRouterType>;
    /**
     * Time Stamp
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a IntelligentPromptRouter resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IntelligentPromptRouterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IntelligentPromptRouter resource.
 */
export interface IntelligentPromptRouterArgs {
    /**
     * Description of the Prompt Router.
     */
    description?: pulumi.Input<string>;
    /**
     * The default model to use when the routing criteria is not met.
     */
    fallbackModel: pulumi.Input<inputs.bedrock.IntelligentPromptRouterPromptRouterTargetModelArgs>;
    /**
     * List of model configuration
     */
    models: pulumi.Input<pulumi.Input<inputs.bedrock.IntelligentPromptRouterPromptRouterTargetModelArgs>[]>;
    /**
     * Name of the Prompt Router.
     */
    promptRouterName?: pulumi.Input<string>;
    /**
     * Routing criteria for a prompt router.
     */
    routingCriteria: pulumi.Input<inputs.bedrock.IntelligentPromptRouterRoutingCriteriaArgs>;
    /**
     * List of Tags
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
