import * as pulumi from "@pulumi/pulumi";
/**
 * Enable a resource that has been published in the CloudFormation Registry.
 */
export declare function getTypeActivation(args: GetTypeActivationArgs, opts?: pulumi.InvokeOptions): Promise<GetTypeActivationResult>;
export interface GetTypeActivationArgs {
    /**
     * The Amazon Resource Name (ARN) of the extension.
     */
    arn: string;
}
export interface GetTypeActivationResult {
    /**
     * The Amazon Resource Name (ARN) of the extension.
     */
    readonly arn?: string;
    /**
     * The Amazon Resource Number (ARN) assigned to the public extension upon publication
     */
    readonly publicTypeArn?: string;
    /**
     * The reserved publisher id for this type, or the publisher id assigned by CloudFormation for publishing in this region.
     */
    readonly publisherId?: string;
    /**
     * The name of the type being registered.
     *
     * We recommend that type names adhere to the following pattern: company_or_organization::service::type.
     */
    readonly typeName?: string;
    /**
     * An alias to assign to the public extension in this account and region. If you specify an alias for the extension, you must then use the alias to refer to the extension in your templates.
     */
    readonly typeNameAlias?: string;
}
/**
 * Enable a resource that has been published in the CloudFormation Registry.
 */
export declare function getTypeActivationOutput(args: GetTypeActivationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTypeActivationResult>;
export interface GetTypeActivationOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the extension.
     */
    arn: pulumi.Input<string>;
}
