import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type Definition for ContactFlowVersion
 */
export declare class ContactFlowVersion extends pulumi.CustomResource {
    /**
     * Get an existing ContactFlowVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ContactFlowVersion;
    /**
     * Returns true if the given object is an instance of ContactFlowVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ContactFlowVersion;
    /**
     * The ARN of the contact flow this version is tied to.
     */
    readonly contactFlowId: pulumi.Output<string>;
    /**
     * The identifier of the contact flow version (ARN).
     */
    readonly contactFlowVersionArn: pulumi.Output<string>;
    /**
     * The description of the version.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Indicates the checksum value of the latest published flow content
     */
    readonly flowContentSha256: pulumi.Output<string>;
    /**
     * The version number of this revision
     */
    readonly version: pulumi.Output<number>;
    /**
     * Create a ContactFlowVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ContactFlowVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ContactFlowVersion resource.
 */
export interface ContactFlowVersionArgs {
    /**
     * The ARN of the contact flow this version is tied to.
     */
    contactFlowId: pulumi.Input<string>;
    /**
     * The description of the version.
     */
    description?: pulumi.Input<string>;
}
