import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Creates a rule for the specified CON instance.
 */
export declare function getRule(args: GetRuleArgs, opts?: pulumi.InvokeOptions): Promise<GetRuleResult>;
export interface GetRuleArgs {
    /**
     * The Amazon Resource Name (ARN) of the rule.
     */
    ruleArn: string;
}
export interface GetRuleResult {
    /**
     * A list of actions to be run when the rule is triggered.
     */
    readonly actions?: outputs.connect.RuleActions;
    /**
     * The conditions of the rule.
     */
    readonly function?: string;
    /**
     * The name of the rule.
     */
    readonly name?: string;
    /**
     * The publish status of the rule.
     *  *Allowed values*: ``DRAFT`` | ``PUBLISHED``
     */
    readonly publishStatus?: enums.connect.RulePublishStatus;
    /**
     * The Amazon Resource Name (ARN) of the rule.
     */
    readonly ruleArn?: string;
    /**
     * The tags used to organize, track, or control access for this resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Creates a rule for the specified CON instance.
 */
export declare function getRuleOutput(args: GetRuleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRuleResult>;
export interface GetRuleOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the rule.
     */
    ruleArn: pulumi.Input<string>;
}
