import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An ObjectType resource of Amazon Connect Customer Profiles
 */
export declare class ObjectType extends pulumi.CustomResource {
    /**
     * Get an existing ObjectType resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ObjectType;
    /**
     * Returns true if the given object is an instance of ObjectType.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ObjectType;
    /**
     * Indicates whether a profile should be created when data is received.
     */
    readonly allowProfileCreation: pulumi.Output<boolean | undefined>;
    /**
     * The time of this integration got created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Description of the profile object type.
     */
    readonly description: pulumi.Output<string>;
    /**
     * The unique name of the domain.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * The default encryption key
     */
    readonly encryptionKey: pulumi.Output<string | undefined>;
    /**
     * The default number of days until the data within the domain expires.
     */
    readonly expirationDays: pulumi.Output<number | undefined>;
    /**
     * A list of the name and ObjectType field.
     */
    readonly fields: pulumi.Output<outputs.customerprofiles.ObjectTypeFieldMap[] | undefined>;
    /**
     * A list of unique keys that can be used to map data to the profile.
     */
    readonly keys: pulumi.Output<outputs.customerprofiles.ObjectTypeKeyMap[] | undefined>;
    /**
     * The time of this integration got last updated at.
     */
    readonly lastUpdatedAt: pulumi.Output<string>;
    /**
     * The maximum available number of profile objects
     */
    readonly maxAvailableProfileObjectCount: pulumi.Output<number>;
    /**
     * The maximum number of profile objects for this object type
     */
    readonly maxProfileObjectCount: pulumi.Output<number | undefined>;
    /**
     * The name of the profile object type.
     */
    readonly objectTypeName: pulumi.Output<string>;
    /**
     * The format of your sourceLastUpdatedTimestamp that was previously set up.
     */
    readonly sourceLastUpdatedTimestampFormat: pulumi.Output<string | undefined>;
    /**
     * The tags (keys and values) associated with the integration.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * A unique identifier for the object template.
     */
    readonly templateId: pulumi.Output<string | undefined>;
    /**
     * Create a ObjectType resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ObjectTypeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ObjectType resource.
 */
export interface ObjectTypeArgs {
    /**
     * Indicates whether a profile should be created when data is received.
     */
    allowProfileCreation?: pulumi.Input<boolean>;
    /**
     * Description of the profile object type.
     */
    description: pulumi.Input<string>;
    /**
     * The unique name of the domain.
     */
    domainName: pulumi.Input<string>;
    /**
     * The default encryption key
     */
    encryptionKey?: pulumi.Input<string>;
    /**
     * The default number of days until the data within the domain expires.
     */
    expirationDays?: pulumi.Input<number>;
    /**
     * A list of the name and ObjectType field.
     */
    fields?: pulumi.Input<pulumi.Input<inputs.customerprofiles.ObjectTypeFieldMapArgs>[]>;
    /**
     * A list of unique keys that can be used to map data to the profile.
     */
    keys?: pulumi.Input<pulumi.Input<inputs.customerprofiles.ObjectTypeKeyMapArgs>[]>;
    /**
     * The maximum number of profile objects for this object type
     */
    maxProfileObjectCount?: pulumi.Input<number>;
    /**
     * The name of the profile object type.
     */
    objectTypeName?: pulumi.Input<string>;
    /**
     * The format of your sourceLastUpdatedTimestamp that was previously set up.
     */
    sourceLastUpdatedTimestampFormat?: pulumi.Input<string>;
    /**
     * The tags (keys and values) associated with the integration.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * A unique identifier for the object template.
     */
    templateId?: pulumi.Input<string>;
}
