import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DataSync::StorageSystem.
 */
export declare class StorageSystem extends pulumi.CustomResource {
    /**
     * Get an existing StorageSystem resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): StorageSystem;
    /**
     * Returns true if the given object is an instance of StorageSystem.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is StorageSystem;
    /**
     * The ARN of the DataSync agent that connects to and reads from the on-premises storage system's management interface.
     */
    readonly agentArns: pulumi.Output<string[]>;
    /**
     * The ARN of the Amazon CloudWatch log group used to monitor and log discovery job events.
     */
    readonly cloudWatchLogGroupArn: pulumi.Output<string | undefined>;
    /**
     * Indicates whether the DataSync agent can access the on-premises storage system.
     */
    readonly connectivityStatus: pulumi.Output<enums.datasync.StorageSystemConnectivityStatus>;
    /**
     * A familiar name for the on-premises storage system.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The ARN of a secret stored by AWS Secrets Manager.
     */
    readonly secretsManagerArn: pulumi.Output<string>;
    readonly serverConfiguration: pulumi.Output<outputs.datasync.StorageSystemServerConfiguration>;
    readonly serverCredentials: pulumi.Output<outputs.datasync.StorageSystemServerCredentials | undefined>;
    /**
     * The ARN of the on-premises storage system added to DataSync Discovery.
     */
    readonly storageSystemArn: pulumi.Output<string>;
    /**
     * The type of on-premises storage system that DataSync Discovery will analyze.
     */
    readonly systemType: pulumi.Output<enums.datasync.StorageSystemSystemType>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a StorageSystem resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StorageSystemArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a StorageSystem resource.
 */
export interface StorageSystemArgs {
    /**
     * The ARN of the DataSync agent that connects to and reads from the on-premises storage system's management interface.
     */
    agentArns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ARN of the Amazon CloudWatch log group used to monitor and log discovery job events.
     */
    cloudWatchLogGroupArn?: pulumi.Input<string>;
    /**
     * A familiar name for the on-premises storage system.
     */
    name?: pulumi.Input<string>;
    serverConfiguration: pulumi.Input<inputs.datasync.StorageSystemServerConfigurationArgs>;
    serverCredentials?: pulumi.Input<inputs.datasync.StorageSystemServerCredentialsArgs>;
    /**
     * The type of on-premises storage system that DataSync Discovery will analyze.
     */
    systemType: pulumi.Input<enums.datasync.StorageSystemSystemType>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
