import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for a Device Farm Network Profile
 */
export declare class NetworkProfile extends pulumi.CustomResource {
    /**
     * Get an existing NetworkProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): NetworkProfile;
    /**
     * Returns true if the given object is an instance of NetworkProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NetworkProfile;
    /**
     * The Amazon Resource Name (ARN) of the network profile. See [Amazon resource names](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html) in the *General Reference guide* .
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The description of the network profile.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The data throughput rate in bits per second, as an integer from 0 to 104857600.
     */
    readonly downlinkBandwidthBits: pulumi.Output<number | undefined>;
    /**
     * Delay time for all packets to destination in milliseconds as an integer from 0 to 2000.
     */
    readonly downlinkDelayMs: pulumi.Output<number | undefined>;
    /**
     * Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000.
     */
    readonly downlinkJitterMs: pulumi.Output<number | undefined>;
    /**
     * Proportion of received packets that fail to arrive from 0 to 100 percent.
     */
    readonly downlinkLossPercent: pulumi.Output<number | undefined>;
    /**
     * The name of the network profile.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the specified project.
     */
    readonly projectArn: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) in the *guide* .
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The data throughput rate in bits per second, as an integer from 0 to 104857600.
     */
    readonly uplinkBandwidthBits: pulumi.Output<number | undefined>;
    /**
     * Delay time for all packets to destination in milliseconds as an integer from 0 to 2000.
     */
    readonly uplinkDelayMs: pulumi.Output<number | undefined>;
    /**
     * Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000.
     */
    readonly uplinkJitterMs: pulumi.Output<number | undefined>;
    /**
     * Proportion of transmitted packets that fail to arrive from 0 to 100 percent.
     */
    readonly uplinkLossPercent: pulumi.Output<number | undefined>;
    /**
     * Create a NetworkProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: NetworkProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a NetworkProfile resource.
 */
export interface NetworkProfileArgs {
    /**
     * The description of the network profile.
     */
    description?: pulumi.Input<string>;
    /**
     * The data throughput rate in bits per second, as an integer from 0 to 104857600.
     */
    downlinkBandwidthBits?: pulumi.Input<number>;
    /**
     * Delay time for all packets to destination in milliseconds as an integer from 0 to 2000.
     */
    downlinkDelayMs?: pulumi.Input<number>;
    /**
     * Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000.
     */
    downlinkJitterMs?: pulumi.Input<number>;
    /**
     * Proportion of received packets that fail to arrive from 0 to 100 percent.
     */
    downlinkLossPercent?: pulumi.Input<number>;
    /**
     * The name of the network profile.
     */
    name?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the specified project.
     */
    projectArn: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) in the *guide* .
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The data throughput rate in bits per second, as an integer from 0 to 104857600.
     */
    uplinkBandwidthBits?: pulumi.Input<number>;
    /**
     * Delay time for all packets to destination in milliseconds as an integer from 0 to 2000.
     */
    uplinkDelayMs?: pulumi.Input<number>;
    /**
     * Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000.
     */
    uplinkJitterMs?: pulumi.Input<number>;
    /**
     * Proportion of transmitted packets that fail to arrive from 0 to 100 percent.
     */
    uplinkLossPercent?: pulumi.Input<number>;
}
