import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::EC2::TrafficMirrorFilter
 */
export declare class TrafficMirrorFilter extends pulumi.CustomResource {
    /**
     * Get an existing TrafficMirrorFilter resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TrafficMirrorFilter;
    /**
     * Returns true if the given object is an instance of TrafficMirrorFilter.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TrafficMirrorFilter;
    /**
     * The ID of a traffic mirror filter.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The description of a traffic mirror filter.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The network service that is associated with the traffic mirror filter.
     */
    readonly networkServices: pulumi.Output<enums.ec2.TrafficMirrorFilterTrafficMirrorNetworkService[] | undefined>;
    /**
     * The tags for a traffic mirror filter.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a TrafficMirrorFilter resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TrafficMirrorFilterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TrafficMirrorFilter resource.
 */
export interface TrafficMirrorFilterArgs {
    /**
     * The description of a traffic mirror filter.
     */
    description?: pulumi.Input<string>;
    /**
     * The network service that is associated with the traffic mirror filter.
     */
    networkServices?: pulumi.Input<pulumi.Input<enums.ec2.TrafficMirrorFilterTrafficMirrorNetworkService>[]>;
    /**
     * The tags for a traffic mirror filter.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
