import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for for AWS::EC2::TrafficMirrorFilterRule
 */
export declare class TrafficMirrorFilterRule extends pulumi.CustomResource {
    /**
     * Get an existing TrafficMirrorFilterRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TrafficMirrorFilterRule;
    /**
     * Returns true if the given object is an instance of TrafficMirrorFilterRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TrafficMirrorFilterRule;
    /**
     * The description of the Traffic Mirror Filter rule.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The destination CIDR block to assign to the Traffic Mirror rule.
     */
    readonly destinationCidrBlock: pulumi.Output<string>;
    /**
     * The destination port range.
     */
    readonly destinationPortRange: pulumi.Output<outputs.ec2.TrafficMirrorFilterRuleTrafficMirrorPortRange | undefined>;
    /**
     * The number of protocol, for example 17 (UDP), to assign to the Traffic Mirror rule.
     */
    readonly protocol: pulumi.Output<number | undefined>;
    /**
     * The action to take on the filtered traffic (accept/reject).
     */
    readonly ruleAction: pulumi.Output<string>;
    /**
     * The number of the Traffic Mirror rule.
     */
    readonly ruleNumber: pulumi.Output<number>;
    /**
     * The source CIDR block to assign to the Traffic Mirror Filter rule.
     */
    readonly sourceCidrBlock: pulumi.Output<string>;
    /**
     * The source port range.
     */
    readonly sourcePortRange: pulumi.Output<outputs.ec2.TrafficMirrorFilterRuleTrafficMirrorPortRange | undefined>;
    /**
     * Any tags assigned to the Traffic Mirror Filter rule.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The direction of traffic (ingress/egress).
     */
    readonly trafficDirection: pulumi.Output<string>;
    /**
     * The ID of the filter that this rule is associated with.
     */
    readonly trafficMirrorFilterId: pulumi.Output<string>;
    /**
     * The ID of the Traffic Mirror Filter rule.
     */
    readonly trafficMirrorFilterRuleId: pulumi.Output<string>;
    /**
     * Create a TrafficMirrorFilterRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TrafficMirrorFilterRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TrafficMirrorFilterRule resource.
 */
export interface TrafficMirrorFilterRuleArgs {
    /**
     * The description of the Traffic Mirror Filter rule.
     */
    description?: pulumi.Input<string>;
    /**
     * The destination CIDR block to assign to the Traffic Mirror rule.
     */
    destinationCidrBlock: pulumi.Input<string>;
    /**
     * The destination port range.
     */
    destinationPortRange?: pulumi.Input<inputs.ec2.TrafficMirrorFilterRuleTrafficMirrorPortRangeArgs>;
    /**
     * The number of protocol, for example 17 (UDP), to assign to the Traffic Mirror rule.
     */
    protocol?: pulumi.Input<number>;
    /**
     * The action to take on the filtered traffic (accept/reject).
     */
    ruleAction: pulumi.Input<string>;
    /**
     * The number of the Traffic Mirror rule.
     */
    ruleNumber: pulumi.Input<number>;
    /**
     * The source CIDR block to assign to the Traffic Mirror Filter rule.
     */
    sourceCidrBlock: pulumi.Input<string>;
    /**
     * The source port range.
     */
    sourcePortRange?: pulumi.Input<inputs.ec2.TrafficMirrorFilterRuleTrafficMirrorPortRangeArgs>;
    /**
     * Any tags assigned to the Traffic Mirror Filter rule.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The direction of traffic (ingress/egress).
     */
    trafficDirection: pulumi.Input<string>;
    /**
     * The ID of the filter that this rule is associated with.
     */
    trafficMirrorFilterId: pulumi.Input<string>;
}
