import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::EMRServerless::Application Type
 */
export declare function getApplication(args: GetApplicationArgs, opts?: pulumi.InvokeOptions): Promise<GetApplicationResult>;
export interface GetApplicationArgs {
    /**
     * The ID of the EMR Serverless Application.
     */
    applicationId: string;
}
export interface GetApplicationResult {
    /**
     * The ID of the EMR Serverless Application.
     */
    readonly applicationId?: string;
    /**
     * The CPU architecture of an application.
     */
    readonly architecture?: enums.emrserverless.ApplicationArchitecture;
    /**
     * The Amazon Resource Name (ARN) of the EMR Serverless Application.
     */
    readonly arn?: string;
    /**
     * Configuration for Auto Start of Application.
     */
    readonly autoStartConfiguration?: outputs.emrserverless.ApplicationAutoStartConfiguration;
    /**
     * Configuration for Auto Stop of Application.
     */
    readonly autoStopConfiguration?: outputs.emrserverless.ApplicationAutoStopConfiguration;
    /**
     * The IAM IdentityCenter configuration for trusted-identity-propagation on this application. Supported with release labels emr-7.8.0 and above.
     */
    readonly identityCenterConfiguration?: outputs.emrserverless.ApplicationIdentityCenterConfiguration;
    /**
     * The image configuration applied to all worker types.
     */
    readonly imageConfiguration?: outputs.emrserverless.ApplicationImageConfigurationInput;
    /**
     * Initial capacity initialized when an Application is started.
     */
    readonly initialCapacity?: outputs.emrserverless.ApplicationInitialCapacityConfigKeyValuePair[];
    /**
     * The interactive configuration object that enables the interactive use cases for an application.
     */
    readonly interactiveConfiguration?: outputs.emrserverless.ApplicationInteractiveConfiguration;
    /**
     * Maximum allowed cumulative resources for an Application. No new resources will be created once the limit is hit.
     */
    readonly maximumCapacity?: outputs.emrserverless.ApplicationMaximumAllowedResources;
    /**
     * A configuration specification to be used when provisioning an application. A configuration consists of a classification, properties, and optional nested configurations. A classification refers to an application-specific configuration file. Properties are the settings you want to change in that file.
     */
    readonly monitoringConfiguration?: outputs.emrserverless.ApplicationMonitoringConfiguration;
    /**
     * Network Configuration for customer VPC connectivity.
     */
    readonly networkConfiguration?: outputs.emrserverless.ApplicationNetworkConfiguration;
    /**
     * EMR release label.
     */
    readonly releaseLabel?: string;
    /**
     * The [Configuration](https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_Configuration.html) specifications of an application. Each configuration consists of a classification and properties. You use this parameter when creating or updating an application. To see the runtimeConfiguration object of an application, run the [GetApplication](https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_GetApplication.html) API operation.
     */
    readonly runtimeConfiguration?: outputs.emrserverless.ApplicationConfigurationObject[];
    /**
     * The scheduler configuration for batch and streaming jobs running on this application. Supported with release labels emr-7.0.0 and above.
     */
    readonly schedulerConfiguration?: outputs.emrserverless.ApplicationSchedulerConfiguration;
    /**
     * Tag map with key and value
     */
    readonly tags?: outputs.Tag[];
    /**
     * The key-value pairs that specify worker type to WorkerTypeSpecificationInput. This parameter must contain all valid worker types for a Spark or Hive application. Valid worker types include Driver and Executor for Spark applications and HiveDriver and TezTask for Hive applications. You can either set image details in this parameter for each worker type, or in imageConfiguration for all worker types.
     */
    readonly workerTypeSpecifications?: {
        [key: string]: outputs.emrserverless.ApplicationWorkerTypeSpecificationInput;
    };
}
/**
 * Resource schema for AWS::EMRServerless::Application Type
 */
export declare function getApplicationOutput(args: GetApplicationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApplicationResult>;
export interface GetApplicationOutputArgs {
    /**
     * The ID of the EMR Serverless Application.
     */
    applicationId: pulumi.Input<string>;
}
