import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::EventSchemas::Discoverer
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myDiscoverer = new aws_native.eventschemas.Discoverer("myDiscoverer", {
 *     sourceArn: "arn:aws:events:us-west-2:012345678910:event-bus/default",
 *     description: "discover all custom schemas",
 * });
 *
 * ```
 */
export declare class Discoverer extends pulumi.CustomResource {
    /**
     * Get an existing Discoverer resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Discoverer;
    /**
     * Returns true if the given object is an instance of Discoverer.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Discoverer;
    /**
     * Defines whether event schemas from other accounts are discovered. Default is True.
     */
    readonly crossAccount: pulumi.Output<boolean | undefined>;
    /**
     * A description for the discoverer.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ARN of the discoverer.
     */
    readonly discovererArn: pulumi.Output<string>;
    /**
     * The Id of the discoverer.
     */
    readonly discovererId: pulumi.Output<string>;
    /**
     * The ARN of the event bus.
     */
    readonly sourceArn: pulumi.Output<string>;
    /**
     * Defines the current state of the discoverer.
     */
    readonly state: pulumi.Output<string>;
    /**
     * Tags associated with the resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Discoverer resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DiscovererArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Discoverer resource.
 */
export interface DiscovererArgs {
    /**
     * Defines whether event schemas from other accounts are discovered. Default is True.
     */
    crossAccount?: pulumi.Input<boolean>;
    /**
     * A description for the discoverer.
     */
    description?: pulumi.Input<string>;
    /**
     * The ARN of the event bus.
     */
    sourceArn: pulumi.Input<string>;
    /**
     * Tags associated with the resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
