import * as pulumi from "@pulumi/pulumi";
/**
 * Resource schema for AWS::ImageBuilder::Image
 */
export declare function getImage(args: GetImageArgs, opts?: pulumi.InvokeOptions): Promise<GetImageResult>;
export interface GetImageArgs {
    /**
     * The Amazon Resource Name (ARN) of the image.
     */
    arn: string;
}
export interface GetImageResult {
    /**
     * The Amazon Resource Name (ARN) of the image.
     */
    readonly arn?: string;
    /**
     * The execution role name/ARN for the image build, if provided
     */
    readonly executionRole?: string;
    /**
     * The AMI ID of the EC2 AMI in current region.
     */
    readonly imageId?: string;
    /**
     * URI for containers created in current Region with default ECR image tag
     */
    readonly imageUri?: string;
    /**
     * The name of the image.
     */
    readonly name?: string;
    /**
     * The tags associated with the image.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * Resource schema for AWS::ImageBuilder::Image
 */
export declare function getImageOutput(args: GetImageOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetImageResult>;
export interface GetImageOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the image.
     */
    arn: pulumi.Input<string>;
}
