import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * resource definition
 */
export declare function getSoftwarePackageVersion(args: GetSoftwarePackageVersionArgs, opts?: pulumi.InvokeOptions): Promise<GetSoftwarePackageVersionResult>;
export interface GetSoftwarePackageVersionArgs {
    /**
     * The name of the associated software package.
     */
    packageName: string;
    /**
     * The name of the new package version.
     */
    versionName: string;
}
export interface GetSoftwarePackageVersionResult {
    readonly artifact?: outputs.iot.SoftwarePackageVersionPackageVersionArtifact;
    /**
     * Metadata that can be used to define a package version’s configuration. For example, the S3 file location, configuration options that are being sent to the device or fleet.
     *
     * The combined size of all the attributes on a package version is limited to 3KB.
     */
    readonly attributes?: {
        [key: string]: string;
    };
    /**
     * A summary of the package version being created. This can be used to outline the package's contents or purpose.
     */
    readonly description?: string;
    /**
     * Error reason for a package version failure during creation or update.
     */
    readonly errorReason?: string;
    /**
     * The Amazon Resource Name (ARN) for the package.
     */
    readonly packageVersionArn?: string;
    /**
     * The inline json job document associated with a software package version
     */
    readonly recipe?: string;
    readonly sbom?: outputs.iot.SoftwarePackageVersionSbom;
    readonly sbomValidationStatus?: enums.iot.SoftwarePackageVersionSbomValidationStatus;
    /**
     * The status of the package version. For more information, see [Package version lifecycle](https://docs.aws.amazon.com/iot/latest/developerguide/preparing-to-use-software-package-catalog.html#package-version-lifecycle) .
     */
    readonly status?: enums.iot.SoftwarePackageVersionPackageVersionStatus;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * resource definition
 */
export declare function getSoftwarePackageVersionOutput(args: GetSoftwarePackageVersionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSoftwarePackageVersionResult>;
export interface GetSoftwarePackageVersionOutputArgs {
    /**
     * The name of the associated software package.
     */
    packageName: pulumi.Input<string>;
    /**
     * The name of the new package version.
     */
    versionName: pulumi.Input<string>;
}
