import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::IoTAnalytics::Dataset
 */
export declare function getDataset(args: GetDatasetArgs, opts?: pulumi.InvokeOptions): Promise<GetDatasetResult>;
export interface GetDatasetArgs {
    /**
     * The name of the dataset.
     */
    datasetName: string;
}
export interface GetDatasetResult {
    /**
     * The `DatasetAction` objects that automatically create the dataset contents.
     */
    readonly actions?: outputs.iotanalytics.DatasetAction[];
    /**
     * When dataset contents are created they are delivered to destinations specified here.
     */
    readonly contentDeliveryRules?: outputs.iotanalytics.DatasetContentDeliveryRule[];
    readonly id?: string;
    /**
     * A list of data rules that send notifications to CloudWatch, when data arrives late. To specify `lateDataRules` , the dataset must use a [DeltaTimer](https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html) filter.
     */
    readonly lateDataRules?: outputs.iotanalytics.DatasetLateDataRule[];
    /**
     * Optional. How long, in days, message data is kept for the dataset.
     */
    readonly retentionPeriod?: outputs.iotanalytics.DatasetRetentionPeriod;
    /**
     * Metadata which can be used to manage the data set.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags?: outputs.Tag[];
    /**
     * The `DatasetTrigger` objects that specify when the dataset is automatically updated.
     */
    readonly triggers?: outputs.iotanalytics.DatasetTrigger[];
    /**
     * Optional. How many versions of dataset contents are kept. If not specified or set to null, only the latest version plus the latest succeeded version (if they are different) are kept for the time period specified by the `retentionPeriod` parameter. For more information, see [Keeping Multiple Versions of AWS IoT Analytics datasets](https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions) in the *AWS IoT Analytics User Guide* .
     */
    readonly versioningConfiguration?: outputs.iotanalytics.DatasetVersioningConfiguration;
}
/**
 * Resource Type definition for AWS::IoTAnalytics::Dataset
 */
export declare function getDatasetOutput(args: GetDatasetOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDatasetResult>;
export interface GetDatasetOutputArgs {
    /**
     * The name of the dataset.
     */
    datasetName: pulumi.Input<string>;
}
