import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Create and manage FUOTA tasks.
 */
export declare function getFuotaTask(args: GetFuotaTaskArgs, opts?: pulumi.InvokeOptions): Promise<GetFuotaTaskResult>;
export interface GetFuotaTaskArgs {
    /**
     * FUOTA task id. Returned after successful create.
     */
    id: string;
}
export interface GetFuotaTaskResult {
    /**
     * FUOTA task arn. Returned after successful create.
     */
    readonly arn?: string;
    /**
     * Multicast group to associate. Only for update request.
     */
    readonly associateMulticastGroup?: string;
    /**
     * Wireless device to associate. Only for update request.
     */
    readonly associateWirelessDevice?: string;
    /**
     * FUOTA task description
     */
    readonly description?: string;
    /**
     * Multicast group to disassociate. Only for update request.
     */
    readonly disassociateMulticastGroup?: string;
    /**
     * Wireless device to disassociate. Only for update request.
     */
    readonly disassociateWirelessDevice?: string;
    /**
     * FUOTA task firmware update image binary S3 link
     */
    readonly firmwareUpdateImage?: string;
    /**
     * FUOTA task firmware IAM role for reading S3
     */
    readonly firmwareUpdateRole?: string;
    /**
     * FUOTA task status. Returned after successful read.
     */
    readonly fuotaTaskStatus?: string;
    /**
     * FUOTA task id. Returned after successful create.
     */
    readonly id?: string;
    /**
     * FUOTA task LoRaWAN
     */
    readonly loRaWan?: outputs.iotwireless.FuotaTaskLoRaWan;
    /**
     * Name of FUOTA task
     */
    readonly name?: string;
    /**
     * A list of key-value pairs that contain metadata for the FUOTA task.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Create and manage FUOTA tasks.
 */
export declare function getFuotaTaskOutput(args: GetFuotaTaskOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFuotaTaskResult>;
export interface GetFuotaTaskOutputArgs {
    /**
     * FUOTA task id. Returned after successful create.
     */
    id: pulumi.Input<string>;
}
