import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Kendra DataSource
 */
export declare function getDataSource(args: GetDataSourceArgs, opts?: pulumi.InvokeOptions): Promise<GetDataSourceResult>;
export interface GetDataSourceArgs {
    /**
     * The identifier for the data source. For example:
     *
     * `b8cae438-6787-4091-8897-684a652bbb0a` .
     */
    id: string;
    /**
     * The identifier of the index you want to use with the data source connector.
     */
    indexId: string;
}
export interface GetDataSourceResult {
    /**
     * The Amazon Resource Name (ARN) of the data source. For example:
     *
     * `arn:aws:kendra:us-west-2:111122223333:index/335c3741-41df-46a6-b5d3-61f85b787884/data-source/b8cae438-6787-4091-8897-684a652bbb0a`
     */
    readonly arn?: string;
    /**
     * Configuration information for altering document metadata and content during the document ingestion process.
     */
    readonly customDocumentEnrichmentConfiguration?: outputs.kendra.DataSourceCustomDocumentEnrichmentConfiguration;
    /**
     * Configuration information for an Amazon Kendra data source. The contents of the configuration depend on the type of data source. You can only specify one type of data source in the configuration.
     *
     * You can't specify the `Configuration` parameter when the `Type` parameter is set to `CUSTOM` .
     *
     * The `Configuration` parameter is required for all other data sources.
     */
    readonly dataSourceConfiguration?: outputs.kendra.DataSourceConfiguration;
    /**
     * A description for the data source connector.
     */
    readonly description?: string;
    /**
     * The identifier for the data source. For example:
     *
     * `b8cae438-6787-4091-8897-684a652bbb0a` .
     */
    readonly id?: string;
    /**
     * The code for a language. This shows a supported language for all documents in the data source. English is supported by default. For more information on supported languages, including their codes, see [Adding documents in languages other than English](https://docs.aws.amazon.com/kendra/latest/dg/in-adding-languages.html) .
     */
    readonly languageCode?: string;
    /**
     * The name of the data source.
     */
    readonly name?: string;
    /**
     * The Amazon Resource Name (ARN) of a role with permission to access the data source.
     *
     * You can't specify the `RoleArn` parameter when the `Type` parameter is set to `CUSTOM` .
     *
     * The `RoleArn` parameter is required for all other data sources.
     */
    readonly roleArn?: string;
    /**
     * Sets the frequency that Amazon Kendra checks the documents in your data source and updates the index. If you don't set a schedule, Amazon Kendra doesn't periodically update the index.
     */
    readonly schedule?: string;
    /**
     * Tags for labeling the data source
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Kendra DataSource
 */
export declare function getDataSourceOutput(args: GetDataSourceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDataSourceResult>;
export interface GetDataSourceOutputArgs {
    /**
     * The identifier for the data source. For example:
     *
     * `b8cae438-6787-4091-8897-684a652bbb0a` .
     */
    id: pulumi.Input<string>;
    /**
     * The identifier of the index you want to use with the data source connector.
     */
    indexId: pulumi.Input<string>;
}
