import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Amazon Lex conversational bot performing automated tasks such as ordering a pizza, booking a hotel, and so on.
 */
export declare function getBot(args: GetBotArgs, opts?: pulumi.InvokeOptions): Promise<GetBotResult>;
export interface GetBotArgs {
    /**
     * The unique identifier of the bot.
     */
    id: string;
}
export interface GetBotResult {
    /**
     * The Amazon Resource Name (ARN) of the bot.
     */
    readonly arn?: string;
    /**
     * By default, data stored by Amazon Lex is encrypted. The `DataPrivacy` structure provides settings that determine how Amazon Lex handles special cases of securing the data for your bot.
     */
    readonly dataPrivacy?: outputs.lex.DataPrivacyProperties;
    /**
     * The description of the version.
     */
    readonly description?: string;
    /**
     * The unique identifier of the bot.
     */
    readonly id?: string;
    /**
     * The time, in seconds, that Amazon Lex should keep information about a user's conversation with the bot.
     *
     * A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Lex deletes any data provided before the timeout.
     *
     * You can specify between 60 (1 minute) and 86,400 (24 hours) seconds.
     */
    readonly idleSessionTtlInSeconds?: number;
    /**
     * The name of the bot locale.
     */
    readonly name?: string;
    /**
     * The Amazon Resource Name (ARN) of the IAM role used to build and run the bot.
     */
    readonly roleArn?: string;
    /**
     * Specifies configuration settings for the alias used to test the bot. If the `TestBotAliasSettings` property is not specified, the settings are configured with default values.
     */
    readonly testBotAliasSettings?: outputs.lex.BotTestBotAliasSettings;
}
/**
 * Amazon Lex conversational bot performing automated tasks such as ordering a pizza, booking a hotel, and so on.
 */
export declare function getBotOutput(args: GetBotOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetBotResult>;
export interface GetBotOutputArgs {
    /**
     * The unique identifier of the bot.
     */
    id: pulumi.Input<string>;
}
