import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * <p>Represents an origin endpoint that is associated with a channel, offering a dynamically repackaged version of its content through various streaming media protocols. The content can be efficiently disseminated to end-users via a Content Delivery Network (CDN), like Amazon CloudFront.</p>
 */
export declare class OriginEndpoint extends pulumi.CustomResource {
    /**
     * Get an existing OriginEndpoint resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): OriginEndpoint;
    /**
     * Returns true if the given object is an instance of OriginEndpoint.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OriginEndpoint;
    /**
     * <p>The Amazon Resource Name (ARN) associated with the resource.</p>
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the channel group associated with the origin endpoint configuration.
     */
    readonly channelGroupName: pulumi.Output<string>;
    /**
     * The channel name associated with the origin endpoint.
     */
    readonly channelName: pulumi.Output<string>;
    /**
     * The container type associated with the origin endpoint configuration.
     */
    readonly containerType: pulumi.Output<enums.mediapackagev2.OriginEndpointContainerType>;
    /**
     * <p>The date and time the origin endpoint was created.</p>
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The egress domain URL for stream delivery from MediaPackage.
     */
    readonly dashManifestUrls: pulumi.Output<string[]>;
    /**
     * <p>A DASH manifest configuration.</p>
     */
    readonly dashManifests: pulumi.Output<outputs.mediapackagev2.OriginEndpointDashManifestConfiguration[] | undefined>;
    /**
     * <p>Enter any descriptive text that helps you to identify the origin endpoint.</p>
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The failover settings for the endpoint.
     */
    readonly forceEndpointErrorConfiguration: pulumi.Output<outputs.mediapackagev2.OriginEndpointForceEndpointErrorConfiguration | undefined>;
    /**
     * The egress domain URL for stream delivery from MediaPackage.
     */
    readonly hlsManifestUrls: pulumi.Output<string[]>;
    /**
     * <p>An HTTP live streaming (HLS) manifest configuration.</p>
     */
    readonly hlsManifests: pulumi.Output<outputs.mediapackagev2.OriginEndpointHlsManifestConfiguration[] | undefined>;
    /**
     * The egress domain URL for stream delivery from MediaPackage.
     */
    readonly lowLatencyHlsManifestUrls: pulumi.Output<string[]>;
    /**
     * <p>A low-latency HLS manifest configuration.</p>
     */
    readonly lowLatencyHlsManifests: pulumi.Output<outputs.mediapackagev2.OriginEndpointLowLatencyHlsManifestConfiguration[] | undefined>;
    /**
     * <p>The date and time the origin endpoint was modified.</p>
     */
    readonly modifiedAt: pulumi.Output<string>;
    /**
     * The name of the origin endpoint associated with the origin endpoint configuration.
     */
    readonly originEndpointName: pulumi.Output<string>;
    /**
     * The segment associated with the origin endpoint.
     */
    readonly segment: pulumi.Output<outputs.mediapackagev2.OriginEndpointSegment | undefined>;
    /**
     * <p>The size of the window (in seconds) to create a window of the live stream that's available for on-demand viewing. Viewers can start-over or catch-up on content that falls within the window. The maximum startover window is 1,209,600 seconds (14 days).</p>
     */
    readonly startoverWindowSeconds: pulumi.Output<number | undefined>;
    /**
     * The tags associated with the origin endpoint.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a OriginEndpoint resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: OriginEndpointArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a OriginEndpoint resource.
 */
export interface OriginEndpointArgs {
    /**
     * The name of the channel group associated with the origin endpoint configuration.
     */
    channelGroupName: pulumi.Input<string>;
    /**
     * The channel name associated with the origin endpoint.
     */
    channelName: pulumi.Input<string>;
    /**
     * The container type associated with the origin endpoint configuration.
     */
    containerType: pulumi.Input<enums.mediapackagev2.OriginEndpointContainerType>;
    /**
     * <p>A DASH manifest configuration.</p>
     */
    dashManifests?: pulumi.Input<pulumi.Input<inputs.mediapackagev2.OriginEndpointDashManifestConfigurationArgs>[]>;
    /**
     * <p>Enter any descriptive text that helps you to identify the origin endpoint.</p>
     */
    description?: pulumi.Input<string>;
    /**
     * The failover settings for the endpoint.
     */
    forceEndpointErrorConfiguration?: pulumi.Input<inputs.mediapackagev2.OriginEndpointForceEndpointErrorConfigurationArgs>;
    /**
     * <p>An HTTP live streaming (HLS) manifest configuration.</p>
     */
    hlsManifests?: pulumi.Input<pulumi.Input<inputs.mediapackagev2.OriginEndpointHlsManifestConfigurationArgs>[]>;
    /**
     * <p>A low-latency HLS manifest configuration.</p>
     */
    lowLatencyHlsManifests?: pulumi.Input<pulumi.Input<inputs.mediapackagev2.OriginEndpointLowLatencyHlsManifestConfigurationArgs>[]>;
    /**
     * The name of the origin endpoint associated with the origin endpoint configuration.
     */
    originEndpointName?: pulumi.Input<string>;
    /**
     * The segment associated with the origin endpoint.
     */
    segment?: pulumi.Input<inputs.mediapackagev2.OriginEndpointSegmentArgs>;
    /**
     * <p>The size of the window (in seconds) to create a window of the live stream that's available for on-demand viewing. Viewers can start-over or catch-up on content that falls within the window. The maximum startover window is 1,209,600 seconds (14 days).</p>
     */
    startoverWindowSeconds?: pulumi.Input<number>;
    /**
     * The tags associated with the origin endpoint.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
