import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::Neptune::DBInstance resource creates an Amazon Neptune DB instance.
 */
export declare function getDbInstance(args: GetDbInstanceArgs, opts?: pulumi.InvokeOptions): Promise<GetDbInstanceResult>;
export interface GetDbInstanceArgs {
    /**
     * Contains a user-supplied database identifier. This identifier is the unique key that identifies a DB instance.
     */
    dbInstanceIdentifier: string;
}
export interface GetDbInstanceResult {
    /**
     * Indicates that minor version patches are applied automatically.
     *
     * When updating this property, some interruptions may occur.
     */
    readonly autoMinorVersionUpgrade?: boolean;
    /**
     * Contains the name of the compute and memory capacity class of the DB instance.
     *
     * If you update this property, some interruptions may occur.
     */
    readonly dbInstanceClass?: string;
    /**
     * The name of an existing DB parameter group or a reference to an AWS::Neptune::DBParameterGroup resource created in the template. If any of the data members of the referenced parameter group are changed during an update, the DB instance might need to be restarted, which causes some interruption. If the parameter group contains static parameters, whether they were changed or not, an update triggers a reboot.
     */
    readonly dbParameterGroupName?: string;
    /**
     * The connection endpoint for the database. For example: `mystack-mydb-1apw1j4phylrk.cg034hpkmmjt.us-east-2.rds.amazonaws.com`.
     */
    readonly endpoint?: string;
    /**
     * The port number on which the database accepts connections. For example: `8182`.
     */
    readonly port?: string;
    /**
     * Specifies the weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
     */
    readonly preferredMaintenanceWindow?: string;
    /**
     * An arbitrary set of tags (key-value pairs) for this DB instance.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::Neptune::DBInstance resource creates an Amazon Neptune DB instance.
 */
export declare function getDbInstanceOutput(args: GetDbInstanceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDbInstanceResult>;
export interface GetDbInstanceOutputArgs {
    /**
     * Contains a user-supplied database identifier. This identifier is the unique key that identifies a DB instance.
     */
    dbInstanceIdentifier: pulumi.Input<string>;
}
