import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource type definition for AWS::NetworkFirewall::VpcEndpointAssociation
 */
export declare class VpcEndpointAssociation extends pulumi.CustomResource {
    /**
     * Get an existing VpcEndpointAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcEndpointAssociation;
    /**
     * Returns true if the given object is an instance of VpcEndpointAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcEndpointAssociation;
    /**
     * A description of the VPC endpoint association.
     */
    readonly description: pulumi.Output<string | undefined>;
    readonly endpointId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the firewall.
     */
    readonly firewallArn: pulumi.Output<string>;
    /**
     * The ID for a subnet that's used in an association with a firewall. This is used in `CreateFirewall` , `AssociateSubnets` , and `CreateVpcEndpointAssociation` . AWS Network Firewall creates an instance of the associated firewall in each subnet that you specify, to filter traffic in the subnet's Availability Zone.
     */
    readonly subnetMapping: pulumi.Output<outputs.networkfirewall.VpcEndpointAssociationSubnetMapping>;
    /**
     * The key:value pairs to associate with the resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of a VPC endpoint association.
     */
    readonly vpcEndpointAssociationArn: pulumi.Output<string>;
    /**
     * The unique identifier of the VPC endpoint association.
     */
    readonly vpcEndpointAssociationId: pulumi.Output<string>;
    /**
     * The unique identifier of the VPC for the endpoint association.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a VpcEndpointAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcEndpointAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcEndpointAssociation resource.
 */
export interface VpcEndpointAssociationArgs {
    /**
     * A description of the VPC endpoint association.
     */
    description?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the firewall.
     */
    firewallArn: pulumi.Input<string>;
    /**
     * The ID for a subnet that's used in an association with a firewall. This is used in `CreateFirewall` , `AssociateSubnets` , and `CreateVpcEndpointAssociation` . AWS Network Firewall creates an instance of the associated firewall in each subnet that you specify, to filter traffic in the subnet's Availability Zone.
     */
    subnetMapping: pulumi.Input<inputs.networkfirewall.VpcEndpointAssociationSubnetMappingArgs>;
    /**
     * The key:value pairs to associate with the resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The unique identifier of the VPC for the endpoint association.
     */
    vpcId: pulumi.Input<string>;
}
