import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The AWS::ODB::CloudAutonomousVmCluster resource creates a Cloud Autonomous VM Cluster
 */
export declare class CloudAutonomousVmCluster extends pulumi.CustomResource {
    /**
     * Get an existing CloudAutonomousVmCluster resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CloudAutonomousVmCluster;
    /**
     * Returns true if the given object is an instance of CloudAutonomousVmCluster.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudAutonomousVmCluster;
    /**
     * The percentage of data storage currently in use for Autonomous Databases in the Autonomous VM cluster.
     */
    readonly autonomousDataStoragePercentage: pulumi.Output<number>;
    /**
     * The data storage size allocated for Autonomous Databases in the Autonomous VM cluster, in TB.
     */
    readonly autonomousDataStorageSizeInTbs: pulumi.Output<number | undefined>;
    /**
     * The available data storage space for Autonomous Databases in the Autonomous VM cluster, in TB.
     */
    readonly availableAutonomousDataStorageSizeInTbs: pulumi.Output<number>;
    /**
     * The number of Autonomous CDBs that you can create with the currently available storage.
     */
    readonly availableContainerDatabases: pulumi.Output<number>;
    /**
     * The number of CPU cores available for allocation to Autonomous Databases.
     */
    readonly availableCpus: pulumi.Output<number>;
    /**
     * The Amazon Resource Name (ARN) for the Autonomous VM cluster.
     */
    readonly cloudAutonomousVmClusterArn: pulumi.Output<string>;
    /**
     * The unique identifier of the Autonomous VM cluster.
     */
    readonly cloudAutonomousVmClusterId: pulumi.Output<string>;
    /**
     * The unique identifier of the Cloud Exadata Infrastructure containing this Autonomous VM cluster.
     */
    readonly cloudExadataInfrastructureId: pulumi.Output<string | undefined>;
    /**
     * The compute model of the Autonomous VM cluster: ECPU or OCPU.
     */
    readonly computeModel: pulumi.Output<enums.odb.CloudAutonomousVmClusterComputeModel>;
    /**
     * The total number of CPU cores in the Autonomous VM cluster.
     */
    readonly cpuCoreCount: pulumi.Output<number>;
    /**
     * The number of CPU cores enabled per node in the Autonomous VM cluster.
     */
    readonly cpuCoreCountPerNode: pulumi.Output<number | undefined>;
    /**
     * The percentage of total CPU cores currently in use in the Autonomous VM cluster.
     */
    readonly cpuPercentage: pulumi.Output<number>;
    /**
     * The total data storage allocated to the Autonomous VM cluster, in GB.
     */
    readonly dataStorageSizeInGbs: pulumi.Output<number>;
    /**
     * The total data storage allocated to the Autonomous VM cluster, in TB.
     */
    readonly dataStorageSizeInTbs: pulumi.Output<number>;
    /**
     * The local node storage allocated to the Autonomous VM cluster, in gigabytes (GB).
     */
    readonly dbNodeStorageSizeInGbs: pulumi.Output<number>;
    /**
     * The list of database servers associated with the Autonomous VM cluster.
     */
    readonly dbServers: pulumi.Output<string[] | undefined>;
    /**
     * The user-provided description of the Autonomous VM cluster.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display name of the Autonomous VM cluster.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * The domain name for the Autonomous VM cluster.
     */
    readonly domain: pulumi.Output<string>;
    /**
     * The minimum value to which you can scale down the Exadata storage, in TB.
     */
    readonly exadataStorageInTbsLowestScaledValue: pulumi.Output<number>;
    /**
     * The hostname for the Autonomous VM cluster.
     */
    readonly hostname: pulumi.Output<string>;
    /**
     * Indicates whether mutual TLS (mTLS) authentication is enabled for the Autonomous VM cluster.
     */
    readonly isMtlsEnabledVmCluster: pulumi.Output<boolean | undefined>;
    /**
     * The Oracle license model that applies to the Autonomous VM cluster. Valid values are LICENSE_INCLUDED or BRING_YOUR_OWN_LICENSE.
     */
    readonly licenseModel: pulumi.Output<enums.odb.CloudAutonomousVmClusterLicenseModel | undefined>;
    /**
     * The scheduling details for the maintenance window. Patching and system updates take place during the maintenance window.
     */
    readonly maintenanceWindow: pulumi.Output<outputs.odb.CloudAutonomousVmClusterMaintenanceWindow | undefined>;
    /**
     * The minimum value to which you can scale down the maximum number of Autonomous CDBs.
     */
    readonly maxAcdsLowestScaledValue: pulumi.Output<number>;
    /**
     * The amount of memory allocated per Oracle Compute Unit, in GB.
     */
    readonly memoryPerOracleComputeUnitInGbs: pulumi.Output<number | undefined>;
    /**
     * The total amount of memory allocated to the Autonomous VM cluster, in gigabytes (GB).
     */
    readonly memorySizeInGbs: pulumi.Output<number>;
    /**
     * The number of database server nodes in the Autonomous VM cluster.
     */
    readonly nodeCount: pulumi.Output<number>;
    /**
     * The number of Autonomous CDBs that can't be provisioned because of resource constraints.
     */
    readonly nonProvisionableAutonomousContainerDatabases: pulumi.Output<number>;
    /**
     * The name of the OCI resource anchor associated with this Autonomous VM cluster.
     */
    readonly ociResourceAnchorName: pulumi.Output<string>;
    /**
     * The URL for accessing the OCI console page for this Autonomous VM cluster.
     */
    readonly ociUrl: pulumi.Output<string>;
    /**
     * The Oracle Cloud Identifier (OCID) of the Autonomous VM cluster.
     */
    readonly ocid: pulumi.Output<string>;
    /**
     * The unique identifier of the ODB network associated with this Autonomous VM cluster.
     */
    readonly odbNetworkId: pulumi.Output<string | undefined>;
    /**
     * The number of Autonomous CDBs that can be provisioned in the Autonomous VM cluster.
     */
    readonly provisionableAutonomousContainerDatabases: pulumi.Output<number>;
    /**
     * The number of Autonomous CDBs currently provisioned in the Autonomous VM cluster.
     */
    readonly provisionedAutonomousContainerDatabases: pulumi.Output<number>;
    /**
     * The number of CPU cores currently provisioned in the Autonomous VM cluster.
     */
    readonly provisionedCpus: pulumi.Output<number>;
    /**
     * The number of CPU cores that can be reclaimed from terminated or scaled-down Autonomous Databases.
     */
    readonly reclaimableCpus: pulumi.Output<number>;
    /**
     * The number of CPU cores reserved for system operations and redundancy.
     */
    readonly reservedCpus: pulumi.Output<number>;
    /**
     * The SCAN listener port for non-TLS (TCP) protocol. The default is 1521.
     */
    readonly scanListenerPortNonTls: pulumi.Output<number | undefined>;
    /**
     * The SCAN listener port for TLS (TCP) protocol. The default is 2484.
     */
    readonly scanListenerPortTls: pulumi.Output<number | undefined>;
    /**
     * The shape of the Exadata infrastructure for the Autonomous VM cluster.
     */
    readonly shape: pulumi.Output<string>;
    /**
     * The tags associated with the Autonomous VM cluster.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The time zone of the Autonomous VM cluster.
     */
    readonly timeZone: pulumi.Output<string | undefined>;
    /**
     * The total number of Autonomous Container Databases that can be created with the allocated local storage.
     */
    readonly totalContainerDatabases: pulumi.Output<number | undefined>;
    /**
     * Create a CloudAutonomousVmCluster resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: CloudAutonomousVmClusterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CloudAutonomousVmCluster resource.
 */
export interface CloudAutonomousVmClusterArgs {
    /**
     * The data storage size allocated for Autonomous Databases in the Autonomous VM cluster, in TB.
     */
    autonomousDataStorageSizeInTbs?: pulumi.Input<number>;
    /**
     * The unique identifier of the Cloud Exadata Infrastructure containing this Autonomous VM cluster.
     */
    cloudExadataInfrastructureId?: pulumi.Input<string>;
    /**
     * The number of CPU cores enabled per node in the Autonomous VM cluster.
     */
    cpuCoreCountPerNode?: pulumi.Input<number>;
    /**
     * The list of database servers associated with the Autonomous VM cluster.
     */
    dbServers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The user-provided description of the Autonomous VM cluster.
     */
    description?: pulumi.Input<string>;
    /**
     * The display name of the Autonomous VM cluster.
     */
    displayName?: pulumi.Input<string>;
    /**
     * Indicates whether mutual TLS (mTLS) authentication is enabled for the Autonomous VM cluster.
     */
    isMtlsEnabledVmCluster?: pulumi.Input<boolean>;
    /**
     * The Oracle license model that applies to the Autonomous VM cluster. Valid values are LICENSE_INCLUDED or BRING_YOUR_OWN_LICENSE.
     */
    licenseModel?: pulumi.Input<enums.odb.CloudAutonomousVmClusterLicenseModel>;
    /**
     * The scheduling details for the maintenance window. Patching and system updates take place during the maintenance window.
     */
    maintenanceWindow?: pulumi.Input<inputs.odb.CloudAutonomousVmClusterMaintenanceWindowArgs>;
    /**
     * The amount of memory allocated per Oracle Compute Unit, in GB.
     */
    memoryPerOracleComputeUnitInGbs?: pulumi.Input<number>;
    /**
     * The unique identifier of the ODB network associated with this Autonomous VM cluster.
     */
    odbNetworkId?: pulumi.Input<string>;
    /**
     * The SCAN listener port for non-TLS (TCP) protocol. The default is 1521.
     */
    scanListenerPortNonTls?: pulumi.Input<number>;
    /**
     * The SCAN listener port for TLS (TCP) protocol. The default is 2484.
     */
    scanListenerPortTls?: pulumi.Input<number>;
    /**
     * The tags associated with the Autonomous VM cluster.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The time zone of the Autonomous VM cluster.
     */
    timeZone?: pulumi.Input<string>;
    /**
     * The total number of Autonomous Container Databases that can be created with the allocated local storage.
     */
    totalContainerDatabases?: pulumi.Input<number>;
}
