import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Omics::SequenceStore
 */
export declare class SequenceStore extends pulumi.CustomResource {
    /**
     * Get an existing SequenceStore resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SequenceStore;
    /**
     * Returns true if the given object is an instance of SequenceStore.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SequenceStore;
    /**
     * Location of the access logs.
     */
    readonly accessLogLocation: pulumi.Output<string | undefined>;
    /**
     * The store's ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * When the store was created.
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * A description for the store.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The algorithm family of the ETag.
     */
    readonly eTagAlgorithmFamily: pulumi.Output<enums.omics.SequenceStoreETagAlgorithmFamily | undefined>;
    /**
     * An S3 location that is used to store files that have failed a direct upload.
     */
    readonly fallbackLocation: pulumi.Output<string | undefined>;
    /**
     * A name for the store.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The tags keys to propagate to the S3 objects associated with read sets in the sequence store.
     */
    readonly propagatedSetLevelTags: pulumi.Output<string[] | undefined>;
    /**
     * This is ARN of the access point associated with the S3 bucket storing read sets.
     */
    readonly s3AccessPointArn: pulumi.Output<string>;
    /**
     * The resource policy that controls S3 access on the store
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Omics::SequenceStore` for more information about the expected schema for this property.
     */
    readonly s3AccessPolicy: pulumi.Output<any | undefined>;
    /**
     * The S3 URI of the sequence store.
     */
    readonly s3Uri: pulumi.Output<string>;
    /**
     * The store's ID.
     */
    readonly sequenceStoreId: pulumi.Output<string>;
    /**
     * Server-side encryption (SSE) settings for the store.
     */
    readonly sseConfig: pulumi.Output<outputs.omics.SequenceStoreSseConfig | undefined>;
    /**
     * Status of the sequence store.
     */
    readonly status: pulumi.Output<enums.omics.SequenceStoreStatus>;
    /**
     * The status message of the sequence store.
     */
    readonly statusMessage: pulumi.Output<string>;
    /**
     * Tags for the store.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The last-updated time of the sequence store.
     */
    readonly updateTime: pulumi.Output<string>;
    /**
     * Create a SequenceStore resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: SequenceStoreArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SequenceStore resource.
 */
export interface SequenceStoreArgs {
    /**
     * Location of the access logs.
     */
    accessLogLocation?: pulumi.Input<string>;
    /**
     * A description for the store.
     */
    description?: pulumi.Input<string>;
    /**
     * The algorithm family of the ETag.
     */
    eTagAlgorithmFamily?: pulumi.Input<enums.omics.SequenceStoreETagAlgorithmFamily>;
    /**
     * An S3 location that is used to store files that have failed a direct upload.
     */
    fallbackLocation?: pulumi.Input<string>;
    /**
     * A name for the store.
     */
    name?: pulumi.Input<string>;
    /**
     * The tags keys to propagate to the S3 objects associated with read sets in the sequence store.
     */
    propagatedSetLevelTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The resource policy that controls S3 access on the store
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Omics::SequenceStore` for more information about the expected schema for this property.
     */
    s3AccessPolicy?: any;
    /**
     * Server-side encryption (SSE) settings for the store.
     */
    sseConfig?: pulumi.Input<inputs.omics.SequenceStoreSseConfigArgs>;
    /**
     * Tags for the store.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
