import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::QBusiness::DataAccessor Resource Type
 */
export declare function getDataAccessor(args: GetDataAccessorArgs, opts?: pulumi.InvokeOptions): Promise<GetDataAccessorResult>;
export interface GetDataAccessorArgs {
    /**
     * The unique identifier of the Amazon Q Business application.
     */
    applicationId: string;
    /**
     * The unique identifier of the data accessor.
     */
    dataAccessorId: string;
}
export interface GetDataAccessorResult {
    /**
     * A list of action configurations specifying the allowed actions and any associated filters.
     */
    readonly actionConfigurations?: outputs.qbusiness.DataAccessorActionConfiguration[];
    /**
     * The authentication configuration details for the data accessor. This specifies how the ISV authenticates when accessing data through this data accessor.
     */
    readonly authenticationDetail?: outputs.qbusiness.DataAccessorAuthenticationDetail;
    /**
     * The timestamp when the data accessor was created.
     */
    readonly createdAt?: string;
    /**
     * The Amazon Resource Name (ARN) of the data accessor.
     */
    readonly dataAccessorArn?: string;
    /**
     * The unique identifier of the data accessor.
     */
    readonly dataAccessorId?: string;
    /**
     * The friendly name of the data accessor.
     */
    readonly displayName?: string;
    /**
     * The Amazon Resource Name (ARN) of the associated IAM Identity Center application.
     */
    readonly idcApplicationArn?: string;
    /**
     * The tags to associate with the data accessor.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The timestamp when the data accessor was last updated.
     */
    readonly updatedAt?: string;
}
/**
 * Definition of AWS::QBusiness::DataAccessor Resource Type
 */
export declare function getDataAccessorOutput(args: GetDataAccessorOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDataAccessorResult>;
export interface GetDataAccessorOutputArgs {
    /**
     * The unique identifier of the Amazon Q Business application.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The unique identifier of the data accessor.
     */
    dataAccessorId: pulumi.Input<string>;
}
