import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::Route53::HealthCheck.
 */
export declare class HealthCheck extends pulumi.CustomResource {
    /**
     * Get an existing HealthCheck resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): HealthCheck;
    /**
     * Returns true if the given object is an instance of HealthCheck.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is HealthCheck;
    /**
     * A complex type that contains information about the health check.
     */
    readonly healthCheckConfig: pulumi.Output<outputs.route53.HealthCheckConfigProperties>;
    /**
     * The identifier that Amazon Route 53 assigned to the health check when you created it. When you add or update a resource record set, you use this value to specify which health check to use. The value can be up to 64 characters long.
     */
    readonly healthCheckId: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly healthCheckTags: pulumi.Output<outputs.route53.HealthCheckTag[] | undefined>;
    /**
     * Create a HealthCheck resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: HealthCheckArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a HealthCheck resource.
 */
export interface HealthCheckArgs {
    /**
     * A complex type that contains information about the health check.
     */
    healthCheckConfig: pulumi.Input<inputs.route53.HealthCheckConfigPropertiesArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    healthCheckTags?: pulumi.Input<pulumi.Input<inputs.route53.HealthCheckTagArgs>[]>;
}
