import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::S3Express::DirectoryBucket.
 */
export declare function getDirectoryBucket(args: GetDirectoryBucketArgs, opts?: pulumi.InvokeOptions): Promise<GetDirectoryBucketResult>;
export interface GetDirectoryBucketArgs {
    /**
     * Specifies a name for the bucket. The bucket name must contain only lowercase letters, numbers, and hyphens (-). A directory bucket name must be unique in the chosen Availability Zone or Local Zone. The bucket name must also follow the format 'bucket_base_name--zone_id--x-s3'. The zone_id can be the ID of an Availability Zone or a Local Zone. If you don't specify a name, AWS CloudFormation generates a unique physical ID and uses that ID for the bucket name.
     */
    bucketName: string;
}
export interface GetDirectoryBucketResult {
    /**
     * Returns the Amazon Resource Name (ARN) of the specified bucket.
     */
    readonly arn?: string;
    /**
     * Returns the code for the Availability Zone or Local Zone where the directory bucket was created. An example for the code of an Availability Zone is 'us-east-1f'.
     */
    readonly availabilityZoneName?: string;
    /**
     * Specifies default encryption for a bucket using server-side encryption with Amazon S3 managed keys (SSE-S3) or AWS KMS keys (SSE-KMS). For information about default encryption for directory buckets, see [Setting and monitoring default encryption for directory buckets](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-bucket-encryption.html) in the *Amazon S3 User Guide* .
     */
    readonly bucketEncryption?: outputs.s3express.DirectoryBucketBucketEncryption;
    /**
     * Lifecycle rules that define how Amazon S3 Express manages objects during their lifetime.
     */
    readonly lifecycleConfiguration?: outputs.s3express.DirectoryBucketLifecycleConfiguration;
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::S3Express::DirectoryBucket.
 */
export declare function getDirectoryBucketOutput(args: GetDirectoryBucketOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDirectoryBucketResult>;
export interface GetDirectoryBucketOutputArgs {
    /**
     * Specifies a name for the bucket. The bucket name must contain only lowercase letters, numbers, and hyphens (-). A directory bucket name must be unique in the chosen Availability Zone or Local Zone. The bucket name must also follow the format 'bucket_base_name--zone_id--x-s3'. The zone_id can be the ID of an Availability Zone or a Local Zone. If you don't specify a name, AWS CloudFormation generates a unique physical ID and uses that ID for the bucket name.
     */
    bucketName: pulumi.Input<string>;
}
