import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type Definition for AWS::S3Outposts::AccessPoint
 */
export declare class AccessPoint extends pulumi.CustomResource {
    /**
     * Get an existing AccessPoint resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AccessPoint;
    /**
     * Returns true if the given object is an instance of AccessPoint.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccessPoint;
    /**
     * The Amazon Resource Name (ARN) of the specified AccessPoint.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the bucket you want to associate this AccessPoint with.
     */
    readonly bucket: pulumi.Output<string>;
    /**
     * A name for the AccessPoint.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The access point policy associated with this access point.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::S3Outposts::AccessPoint` for more information about the expected schema for this property.
     */
    readonly policy: pulumi.Output<any | undefined>;
    /**
     * Virtual Private Cloud (VPC) from which requests can be made to the AccessPoint.
     */
    readonly vpcConfiguration: pulumi.Output<outputs.s3outposts.AccessPointVpcConfiguration>;
    /**
     * Create a AccessPoint resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AccessPointArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AccessPoint resource.
 */
export interface AccessPointArgs {
    /**
     * The Amazon Resource Name (ARN) of the bucket you want to associate this AccessPoint with.
     */
    bucket: pulumi.Input<string>;
    /**
     * A name for the AccessPoint.
     */
    name?: pulumi.Input<string>;
    /**
     * The access point policy associated with this access point.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::S3Outposts::AccessPoint` for more information about the expected schema for this property.
     */
    policy?: any;
    /**
     * Virtual Private Cloud (VPC) from which requests can be made to the AccessPoint.
     */
    vpcConfiguration: pulumi.Input<inputs.s3outposts.AccessPointVpcConfigurationArgs>;
}
