import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::S3Tables::Table
 */
export declare class Table extends pulumi.CustomResource {
    /**
     * Get an existing Table resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Table;
    /**
     * Returns true if the given object is an instance of Table.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Table;
    readonly compaction: pulumi.Output<outputs.s3tables.TableCompaction | undefined>;
    /**
     * Contains details about the metadata for an Iceberg table.
     */
    readonly icebergMetadata: pulumi.Output<outputs.s3tables.TableIcebergMetadata | undefined>;
    /**
     * The name of the namespace.
     */
    readonly namespace: pulumi.Output<string>;
    readonly openTableFormat: pulumi.Output<enums.s3tables.TableOpenTableFormat>;
    readonly snapshotManagement: pulumi.Output<outputs.s3tables.TableSnapshotManagement | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the table.
     */
    readonly tableArn: pulumi.Output<string>;
    readonly tableBucketArn: pulumi.Output<string>;
    readonly tableName: pulumi.Output<string>;
    readonly versionToken: pulumi.Output<string>;
    readonly warehouseLocation: pulumi.Output<string>;
    readonly withoutMetadata: pulumi.Output<enums.s3tables.TableWithoutMetadata | undefined>;
    /**
     * Create a Table resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TableArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Table resource.
 */
export interface TableArgs {
    compaction?: pulumi.Input<inputs.s3tables.TableCompactionArgs>;
    /**
     * Contains details about the metadata for an Iceberg table.
     */
    icebergMetadata?: pulumi.Input<inputs.s3tables.TableIcebergMetadataArgs>;
    /**
     * The name of the namespace.
     */
    namespace: pulumi.Input<string>;
    openTableFormat: pulumi.Input<enums.s3tables.TableOpenTableFormat>;
    snapshotManagement?: pulumi.Input<inputs.s3tables.TableSnapshotManagementArgs>;
    tableBucketArn: pulumi.Input<string>;
    tableName?: pulumi.Input<string>;
    withoutMetadata?: pulumi.Input<enums.s3tables.TableWithoutMetadata>;
}
