import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SageMaker::ModelQualityJobDefinition
 */
export declare class ModelQualityJobDefinition extends pulumi.CustomResource {
    /**
     * Get an existing ModelQualityJobDefinition resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ModelQualityJobDefinition;
    /**
     * Returns true if the given object is an instance of ModelQualityJobDefinition.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ModelQualityJobDefinition;
    /**
     * The time at which the job definition was created.
     */
    readonly creationTime: pulumi.Output<string>;
    readonly endpointName: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of job definition.
     */
    readonly jobDefinitionArn: pulumi.Output<string>;
    /**
     * The name of the monitoring job definition.
     */
    readonly jobDefinitionName: pulumi.Output<string | undefined>;
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    readonly jobResources: pulumi.Output<outputs.sagemaker.ModelQualityJobDefinitionMonitoringResources>;
    /**
     * Container image configuration object for the monitoring job.
     */
    readonly modelQualityAppSpecification: pulumi.Output<outputs.sagemaker.ModelQualityJobDefinitionModelQualityAppSpecification>;
    /**
     * Specifies the constraints and baselines for the monitoring job.
     */
    readonly modelQualityBaselineConfig: pulumi.Output<outputs.sagemaker.ModelQualityJobDefinitionModelQualityBaselineConfig | undefined>;
    /**
     * A list of the inputs that are monitored. Currently endpoints are supported.
     */
    readonly modelQualityJobInput: pulumi.Output<outputs.sagemaker.ModelQualityJobDefinitionModelQualityJobInput>;
    /**
     * The output configuration for monitoring jobs.
     */
    readonly modelQualityJobOutputConfig: pulumi.Output<outputs.sagemaker.ModelQualityJobDefinitionMonitoringOutputConfig>;
    /**
     * Specifies the network configuration for the monitoring job.
     */
    readonly networkConfig: pulumi.Output<outputs.sagemaker.ModelQualityJobDefinitionNetworkConfig | undefined>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * A time limit for how long the monitoring job is allowed to run before stopping.
     */
    readonly stoppingCondition: pulumi.Output<outputs.sagemaker.ModelQualityJobDefinitionStoppingCondition | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a ModelQualityJobDefinition resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ModelQualityJobDefinitionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ModelQualityJobDefinition resource.
 */
export interface ModelQualityJobDefinitionArgs {
    endpointName?: pulumi.Input<string>;
    /**
     * The name of the monitoring job definition.
     */
    jobDefinitionName?: pulumi.Input<string>;
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    jobResources: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionMonitoringResourcesArgs>;
    /**
     * Container image configuration object for the monitoring job.
     */
    modelQualityAppSpecification: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionModelQualityAppSpecificationArgs>;
    /**
     * Specifies the constraints and baselines for the monitoring job.
     */
    modelQualityBaselineConfig?: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionModelQualityBaselineConfigArgs>;
    /**
     * A list of the inputs that are monitored. Currently endpoints are supported.
     */
    modelQualityJobInput: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionModelQualityJobInputArgs>;
    /**
     * The output configuration for monitoring jobs.
     */
    modelQualityJobOutputConfig: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionMonitoringOutputConfigArgs>;
    /**
     * Specifies the network configuration for the monitoring job.
     */
    networkConfig?: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionNetworkConfigArgs>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
     */
    roleArn: pulumi.Input<string>;
    /**
     * A time limit for how long the monitoring job is allowed to run before stopping.
     */
    stoppingCondition?: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionStoppingConditionArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
