import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * The AWS::SecurityHub::AggregatorV2 resource represents the AWS Security Hub AggregatorV2 in your account. One aggregatorv2 resource is created for each account in non opt-in region in which you configure region linking mode.
 */
export declare class AggregatorV2 extends pulumi.CustomResource {
    /**
     * Get an existing AggregatorV2 resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AggregatorV2;
    /**
     * Returns true if the given object is an instance of AggregatorV2.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AggregatorV2;
    /**
     * The aggregation Region of the AggregatorV2
     */
    readonly aggregationRegion: pulumi.Output<string>;
    /**
     * The ARN of the AggregatorV2 being created and assigned as the unique identifier
     */
    readonly aggregatorV2Arn: pulumi.Output<string>;
    /**
     * The list of included Regions
     */
    readonly linkedRegions: pulumi.Output<string[]>;
    /**
     * Indicates to link a list of included Regions
     */
    readonly regionLinkingMode: pulumi.Output<enums.securityhub.AggregatorV2RegionLinkingMode>;
    /**
     * A list of key-value pairs to be applied to the AggregatorV2.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a AggregatorV2 resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AggregatorV2Args, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AggregatorV2 resource.
 */
export interface AggregatorV2Args {
    /**
     * The list of included Regions
     */
    linkedRegions: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Indicates to link a list of included Regions
     */
    regionLinkingMode: pulumi.Input<enums.securityhub.AggregatorV2RegionLinkingMode>;
    /**
     * A list of key-value pairs to be applied to the AggregatorV2.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
