import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::SecurityHub::AutomationRuleV2
 */
export declare function getAutomationRuleV2(args: GetAutomationRuleV2Args, opts?: pulumi.InvokeOptions): Promise<GetAutomationRuleV2Result>;
export interface GetAutomationRuleV2Args {
    /**
     * The ARN of the automation rule
     */
    ruleArn: string;
}
export interface GetAutomationRuleV2Result {
    /**
     * A list of actions to be performed when the rule criteria is met
     */
    readonly actions?: outputs.securityhub.AutomationRuleV2AutomationRulesActionV2[];
    /**
     * The timestamp when the V2 automation rule was created.
     */
    readonly createdAt?: string;
    /**
     * The filtering type and configuration of the automation rule.
     */
    readonly criteria?: outputs.securityhub.AutomationRuleV2Criteria;
    /**
     * A description of the automation rule
     */
    readonly description?: string;
    /**
     * The ARN of the automation rule
     */
    readonly ruleArn?: string;
    /**
     * The ID of the automation rule
     */
    readonly ruleId?: string;
    /**
     * The name of the automation rule
     */
    readonly ruleName?: string;
    /**
     * The value for the rule priority
     */
    readonly ruleOrder?: number;
    /**
     * The status of the automation rule
     */
    readonly ruleStatus?: enums.securityhub.AutomationRuleV2RuleStatus;
    /**
     * A list of key-value pairs associated with the V2 automation rule.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * The timestamp when the V2 automation rule was updated.
     */
    readonly updatedAt?: string;
}
/**
 * Resource schema for AWS::SecurityHub::AutomationRuleV2
 */
export declare function getAutomationRuleV2Output(args: GetAutomationRuleV2OutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAutomationRuleV2Result>;
export interface GetAutomationRuleV2OutputArgs {
    /**
     * The ARN of the automation rule
     */
    ruleArn: pulumi.Input<string>;
}
