import * as pulumi from "@pulumi/pulumi";
/**
 * The AWS::SecurityHub::HubV2 resource represents the implementation of the AWS Security Hub V2 service in your account. Only one hubv2 resource can created in each region in which you enable Security Hub V2.
 */
export declare function getHubV2(args: GetHubV2Args, opts?: pulumi.InvokeOptions): Promise<GetHubV2Result>;
export interface GetHubV2Args {
    /**
     * The Amazon Resource Name of the Security Hub V2 resource.
     */
    hubV2Arn: string;
}
export interface GetHubV2Result {
    /**
     * The Amazon Resource Name of the Security Hub V2 resource.
     */
    readonly hubV2Arn?: string;
    /**
     * The date and time when the service was enabled in the account.
     */
    readonly subscribedAt?: string;
    /**
     * The tags to add to the hub V2 resource when you enable Security Hub.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * The AWS::SecurityHub::HubV2 resource represents the implementation of the AWS Security Hub V2 service in your account. Only one hubv2 resource can created in each region in which you enable Security Hub V2.
 */
export declare function getHubV2Output(args: GetHubV2OutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetHubV2Result>;
export interface GetHubV2OutputArgs {
    /**
     * The Amazon Resource Name of the Security Hub V2 resource.
     */
    hubV2Arn: pulumi.Input<string>;
}
