import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * The AWS::SecurityHub::OrganizationConfiguration resource represents the configuration of your organization in Security Hub. Only the Security Hub administrator account can create Organization Configuration resource in each region and can opt-in to Central Configuration only in the aggregation region of FindingAggregator.
 */
export declare function getOrganizationConfiguration(args: GetOrganizationConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetOrganizationConfigurationResult>;
export interface GetOrganizationConfigurationArgs {
    /**
     * The identifier of the OrganizationConfiguration being created and assigned as the unique identifier.
     */
    organizationConfigurationIdentifier: string;
}
export interface GetOrganizationConfigurationResult {
    /**
     * Whether to automatically enable Security Hub in new member accounts when they join the organization.
     */
    readonly autoEnable?: boolean;
    /**
     * Whether to automatically enable Security Hub default standards in new member accounts when they join the organization.
     */
    readonly autoEnableStandards?: enums.securityhub.OrganizationConfigurationAutoEnableStandards;
    /**
     * Indicates whether the organization uses local or central configuration.
     */
    readonly configurationType?: enums.securityhub.OrganizationConfigurationConfigurationType;
    /**
     * Whether the maximum number of allowed member accounts are already associated with the Security Hub administrator account.
     */
    readonly memberAccountLimitReached?: boolean;
    /**
     * The identifier of the OrganizationConfiguration being created and assigned as the unique identifier.
     */
    readonly organizationConfigurationIdentifier?: string;
    /**
     * Describes whether central configuration could be enabled as the ConfigurationType for the organization.
     */
    readonly status?: enums.securityhub.OrganizationConfigurationStatus;
    /**
     * Provides an explanation if the value of Status is equal to FAILED when ConfigurationType is equal to CENTRAL.
     */
    readonly statusMessage?: string;
}
/**
 * The AWS::SecurityHub::OrganizationConfiguration resource represents the configuration of your organization in Security Hub. Only the Security Hub administrator account can create Organization Configuration resource in each region and can opt-in to Central Configuration only in the aggregation region of FindingAggregator.
 */
export declare function getOrganizationConfigurationOutput(args: GetOrganizationConfigurationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetOrganizationConfigurationResult>;
export interface GetOrganizationConfigurationOutputArgs {
    /**
     * The identifier of the OrganizationConfiguration being created and assigned as the unique identifier.
     */
    organizationConfigurationIdentifier: pulumi.Input<string>;
}
