import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::SES::ContactList.
 */
export declare class ContactList extends pulumi.CustomResource {
    /**
     * Get an existing ContactList resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ContactList;
    /**
     * Returns true if the given object is an instance of ContactList.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ContactList;
    /**
     * The name of the contact list.
     */
    readonly contactListName: pulumi.Output<string | undefined>;
    /**
     * The description of the contact list.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The tags (keys and values) associated with the contact list.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The topics associated with the contact list.
     */
    readonly topics: pulumi.Output<outputs.ses.ContactListTopic[] | undefined>;
    /**
     * Create a ContactList resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ContactListArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ContactList resource.
 */
export interface ContactListArgs {
    /**
     * The name of the contact list.
     */
    contactListName?: pulumi.Input<string>;
    /**
     * The description of the contact list.
     */
    description?: pulumi.Input<string>;
    /**
     * The tags (keys and values) associated with the contact list.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The topics associated with the contact list.
     */
    topics?: pulumi.Input<pulumi.Input<inputs.ses.ContactListTopicArgs>[]>;
}
