import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Authorizes the Shield Response Team (SRT) to use email and phone to notify contacts about escalations to the SRT and to initiate proactive customer support.
 */
export declare class ProactiveEngagement extends pulumi.CustomResource {
    /**
     * Get an existing ProactiveEngagement resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ProactiveEngagement;
    /**
     * Returns true if the given object is an instance of ProactiveEngagement.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ProactiveEngagement;
    /**
     * The ID of the account that submitted the template.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * A list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you for escalations to the SRT and to initiate proactive customer support.
     * To enable proactive engagement, the contact list must include at least one phone number.
     */
    readonly emergencyContactList: pulumi.Output<outputs.shield.ProactiveEngagementEmergencyContact[]>;
    /**
     * If `ENABLED`, the Shield Response Team (SRT) will use email and phone to notify contacts about escalations to the SRT and to initiate proactive customer support.
     * If `DISABLED`, the SRT will not proactively notify contacts about escalations or to initiate proactive customer support.
     */
    readonly proactiveEngagementStatus: pulumi.Output<enums.shield.ProactiveEngagementStatus>;
    /**
     * Create a ProactiveEngagement resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProactiveEngagementArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ProactiveEngagement resource.
 */
export interface ProactiveEngagementArgs {
    /**
     * A list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you for escalations to the SRT and to initiate proactive customer support.
     * To enable proactive engagement, the contact list must include at least one phone number.
     */
    emergencyContactList: pulumi.Input<pulumi.Input<inputs.shield.ProactiveEngagementEmergencyContactArgs>[]>;
    /**
     * If `ENABLED`, the Shield Response Team (SRT) will use email and phone to notify contacts about escalations to the SRT and to initiate proactive customer support.
     * If `DISABLED`, the SRT will not proactively notify contacts about escalations or to initiate proactive customer support.
     */
    proactiveEngagementStatus: pulumi.Input<enums.shield.ProactiveEngagementStatus>;
}
