import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * AWS::SimSpaceWeaver::Simulation resource creates an AWS Simulation.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myTestSimulation = new aws_native.simspaceweaver.Simulation("myTestSimulation", {
 *     name: "MyTestSimulation",
 *     roleArn: "arn:aws:iam::111122223333:role/my-test-simulation-app-role",
 *     schemaS3Location: {
 *         bucketName: "MyTestSimulationBucket",
 *         objectKey: "MyTestSimulation-schema.yaml",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myTestSimulation = new aws_native.simspaceweaver.Simulation("myTestSimulation", {
 *     name: "MyTestSimulation",
 *     roleArn: "arn:aws:iam::111122223333:role/my-test-simulation-app-role",
 *     schemaS3Location: {
 *         bucketName: "MyTestSimulationBucket",
 *         objectKey: "MyTestSimulation-schema.yaml",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myTestSimulation = new aws_native.simspaceweaver.Simulation("myTestSimulation", {
 *     name: "MyTestSimulation_22-12-15_12_00_00",
 *     roleArn: "arn:aws:iam::111122223333:role/weaver-MyTestSimulation-app-role",
 *     schemaS3Location: {
 *         bucketName: "weaver-mytestsimulation-111122223333-schemas-us-west-2",
 *         objectKey: "MyTestSimulation-schema.yaml",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myTestSimulation = new aws_native.simspaceweaver.Simulation("myTestSimulation", {
 *     name: "MyTestSimulation_22-12-15_12_00_00",
 *     roleArn: "arn:aws:iam::111122223333:role/weaver-MyTestSimulation-app-role",
 *     schemaS3Location: {
 *         bucketName: "weaver-mytestsimulation-111122223333-schemas-us-west-2",
 *         objectKey: "MyTestSimulation-schema.yaml",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myTestSimulation = new aws_native.simspaceweaver.Simulation("myTestSimulation", {
 *     name: "MyTestSimulation_22-12-15_12_00_00",
 *     roleArn: "arn:aws:iam::111122223333:role/weaver-MyTestSimulation-app-role",
 *     schemaS3Location: {
 *         bucketName: "weaver-mytestsimulation-111122223333-artifacts-us-west-2",
 *         objectKey: "MyTestSimulation-schema.yaml",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myTestSimulation = new aws_native.simspaceweaver.Simulation("myTestSimulation", {
 *     name: "MyTestSimulation_22-12-15_12_00_00",
 *     roleArn: "arn:aws:iam::111122223333:role/weaver-MyTestSimulation-app-role",
 *     schemaS3Location: {
 *         bucketName: "weaver-mytestsimulation-111122223333-artifacts-us-west-2",
 *         objectKey: "MyTestSimulation-schema.yaml",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myTestSimulation = new aws_native.simspaceweaver.Simulation("myTestSimulation", {
 *     maximumDuration: "1H",
 *     name: "MyTestSimulation_22-12-15_12_00_00",
 *     roleArn: "arn:aws:iam::111122223333:role/weaver-MyTestSimulation-app-role",
 *     schemaS3Location: {
 *         bucketName: "weaver-mytestsimulation-111122223333-artifacts-us-west-2",
 *         objectKey: "MyTestSimulation-schema.yaml",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myTestSimulation = new aws_native.simspaceweaver.Simulation("myTestSimulation", {
 *     maximumDuration: "1H",
 *     name: "MyTestSimulation_22-12-15_12_00_00",
 *     roleArn: "arn:aws:iam::111122223333:role/weaver-MyTestSimulation-app-role",
 *     schemaS3Location: {
 *         bucketName: "weaver-mytestsimulation-111122223333-artifacts-us-west-2",
 *         objectKey: "MyTestSimulation-schema.yaml",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myTestSimulation = new aws_native.simspaceweaver.Simulation("myTestSimulation", {
 *     maximumDuration: "2D",
 *     name: "MyTestSimulation_from_snapshot",
 *     roleArn: "arn:aws:iam::111122223333:role/weaver-MyTestSimulation-app-role-copy",
 *     snapshotS3Location: {
 *         bucketName: "weaver-mytestsimulation-111122223333-artifacts-us-west-2",
 *         objectKey: "snapshot/MyTestSimulation_22-12-15_12_00_00-230428-1207-13.zip",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myTestSimulation = new aws_native.simspaceweaver.Simulation("myTestSimulation", {
 *     maximumDuration: "2D",
 *     name: "MyTestSimulation_from_snapshot",
 *     roleArn: "arn:aws:iam::111122223333:role/weaver-MyTestSimulation-app-role-copy",
 *     snapshotS3Location: {
 *         bucketName: "weaver-mytestsimulation-111122223333-artifacts-us-west-2",
 *         objectKey: "snapshot/MyTestSimulation_22-12-15_12_00_00-230428-1207-13.zip",
 *     },
 * });
 *
 * ```
 */
export declare class Simulation extends pulumi.CustomResource {
    /**
     * Get an existing Simulation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Simulation;
    /**
     * Returns true if the given object is an instance of Simulation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Simulation;
    /**
     * Json object with all simulation details
     */
    readonly describePayload: pulumi.Output<string>;
    /**
     * The maximum running time of the simulation.
     */
    readonly maximumDuration: pulumi.Output<string | undefined>;
    /**
     * The name of the simulation.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Role ARN.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * The location of the simulation schema in Amazon Simple Storage Service ( Amazon S3 ). For more information about Amazon S3 , see the [*Amazon Simple Storage Service User Guide*](https://docs.aws.amazon.com/AmazonS3/latest/userguide/Welcome.html) .
     *
     * Provide a `SchemaS3Location` to start your simulation from a schema.
     *
     * If you provide a `SchemaS3Location` then you can't provide a `SnapshotS3Location` .
     */
    readonly schemaS3Location: pulumi.Output<outputs.simspaceweaver.SimulationS3Location | undefined>;
    /**
     * The location of the snapshot in Amazon Simple Storage Service ( Amazon S3 ). For more information about Amazon S3 , see the [*Amazon Simple Storage Service User Guide*](https://docs.aws.amazon.com/AmazonS3/latest/userguide/Welcome.html) .
     *
     * Provide a `SnapshotS3Location` to start your simulation from a snapshot.
     *
     * If you provide a `SnapshotS3Location` then you can't provide a `SchemaS3Location` .
     */
    readonly snapshotS3Location: pulumi.Output<outputs.simspaceweaver.SimulationS3Location | undefined>;
    /**
     * Create a Simulation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SimulationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Simulation resource.
 */
export interface SimulationArgs {
    /**
     * The maximum running time of the simulation.
     */
    maximumDuration?: pulumi.Input<string>;
    /**
     * The name of the simulation.
     */
    name?: pulumi.Input<string>;
    /**
     * Role ARN.
     */
    roleArn: pulumi.Input<string>;
    /**
     * The location of the simulation schema in Amazon Simple Storage Service ( Amazon S3 ). For more information about Amazon S3 , see the [*Amazon Simple Storage Service User Guide*](https://docs.aws.amazon.com/AmazonS3/latest/userguide/Welcome.html) .
     *
     * Provide a `SchemaS3Location` to start your simulation from a schema.
     *
     * If you provide a `SchemaS3Location` then you can't provide a `SnapshotS3Location` .
     */
    schemaS3Location?: pulumi.Input<inputs.simspaceweaver.SimulationS3LocationArgs>;
    /**
     * The location of the snapshot in Amazon Simple Storage Service ( Amazon S3 ). For more information about Amazon S3 , see the [*Amazon Simple Storage Service User Guide*](https://docs.aws.amazon.com/AmazonS3/latest/userguide/Welcome.html) .
     *
     * Provide a `SnapshotS3Location` to start your simulation from a snapshot.
     *
     * If you provide a `SnapshotS3Location` then you can't provide a `SchemaS3Location` .
     */
    snapshotS3Location?: pulumi.Input<inputs.simspaceweaver.SimulationS3LocationArgs>;
}
