import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Wisdom::QuickResponse Resource Type.
 */
export declare class QuickResponse extends pulumi.CustomResource {
    /**
     * Get an existing QuickResponse resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): QuickResponse;
    /**
     * Returns true if the given object is an instance of QuickResponse.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is QuickResponse;
    /**
     * The Amazon Connect contact channels this quick response applies to.
     */
    readonly channels: pulumi.Output<enums.wisdom.QuickResponseChannelType[] | undefined>;
    readonly content: pulumi.Output<outputs.wisdom.QuickResponseContentProvider>;
    /**
     * The media type of the quick response content.
     * - Use application/x.quickresponse;format=plain for quick response written in plain text.
     * - Use application/x.quickresponse;format=markdown for quick response written in richtext.
     */
    readonly contentType: pulumi.Output<string | undefined>;
    readonly contents: pulumi.Output<outputs.wisdom.QuickResponseContents>;
    /**
     * The description of the quick response.
     */
    readonly description: pulumi.Output<string | undefined>;
    readonly groupingConfiguration: pulumi.Output<outputs.wisdom.QuickResponseGroupingConfiguration | undefined>;
    /**
     * Whether the quick response is active.
     */
    readonly isActive: pulumi.Output<boolean | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the knowledge base.
     */
    readonly knowledgeBaseArn: pulumi.Output<string>;
    /**
     * The language code value for the language in which the quick response is written. The supported language codes include de_DE, en_US, es_ES, fr_FR, id_ID, it_IT, ja_JP, ko_KR, pt_BR, zh_CN, zh_TW
     */
    readonly language: pulumi.Output<string | undefined>;
    /**
     * The name of the quick response.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the quick response.
     */
    readonly quickResponseArn: pulumi.Output<string>;
    /**
     * The identifier of the quick response.
     */
    readonly quickResponseId: pulumi.Output<string>;
    /**
     * The shortcut key of the quick response. The value should be unique across the knowledge base.
     */
    readonly shortcutKey: pulumi.Output<string | undefined>;
    readonly status: pulumi.Output<enums.wisdom.QuickResponseStatus>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a QuickResponse resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: QuickResponseArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a QuickResponse resource.
 */
export interface QuickResponseArgs {
    /**
     * The Amazon Connect contact channels this quick response applies to.
     */
    channels?: pulumi.Input<pulumi.Input<enums.wisdom.QuickResponseChannelType>[]>;
    content: pulumi.Input<inputs.wisdom.QuickResponseContentProviderArgs>;
    /**
     * The media type of the quick response content.
     * - Use application/x.quickresponse;format=plain for quick response written in plain text.
     * - Use application/x.quickresponse;format=markdown for quick response written in richtext.
     */
    contentType?: pulumi.Input<string>;
    /**
     * The description of the quick response.
     */
    description?: pulumi.Input<string>;
    groupingConfiguration?: pulumi.Input<inputs.wisdom.QuickResponseGroupingConfigurationArgs>;
    /**
     * Whether the quick response is active.
     */
    isActive?: pulumi.Input<boolean>;
    /**
     * The Amazon Resource Name (ARN) of the knowledge base.
     */
    knowledgeBaseArn: pulumi.Input<string>;
    /**
     * The language code value for the language in which the quick response is written. The supported language codes include de_DE, en_US, es_ES, fr_FR, id_ID, it_IT, ja_JP, ko_KR, pt_BR, zh_CN, zh_TW
     */
    language?: pulumi.Input<string>;
    /**
     * The name of the quick response.
     */
    name?: pulumi.Input<string>;
    /**
     * The shortcut key of the quick response. The value should be unique across the knowledge base.
     */
    shortcutKey?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
