import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::WorkspacesInstances::VolumeAssociation
 */
export declare class VolumeAssociation extends pulumi.CustomResource {
    /**
     * Get an existing VolumeAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VolumeAssociation;
    /**
     * Returns true if the given object is an instance of VolumeAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VolumeAssociation;
    /**
     * The device name for the volume attachment
     */
    readonly device: pulumi.Output<string>;
    /**
     * Mode to use when disassociating the volume
     */
    readonly disassociateMode: pulumi.Output<enums.workspacesinstances.VolumeAssociationDisassociateMode | undefined>;
    /**
     * ID of the volume to attach to the workspace instance
     */
    readonly volumeId: pulumi.Output<string>;
    /**
     * ID of the workspace instance to associate with the volume
     */
    readonly workspaceInstanceId: pulumi.Output<string>;
    /**
     * Create a VolumeAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VolumeAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VolumeAssociation resource.
 */
export interface VolumeAssociationArgs {
    /**
     * The device name for the volume attachment
     */
    device: pulumi.Input<string>;
    /**
     * Mode to use when disassociating the volume
     */
    disassociateMode?: pulumi.Input<enums.workspacesinstances.VolumeAssociationDisassociateMode>;
    /**
     * ID of the volume to attach to the workspace instance
     */
    volumeId: pulumi.Input<string>;
    /**
     * ID of the workspace instance to associate with the volume
     */
    workspaceInstanceId: pulumi.Input<string>;
}
